@@ -475,11 +475,11 @@ static gint AVScanOPClamAVScanFile(
 	scanner_opts_struct *scanner_opts
 )
 {
-	unsigned long int scanned_blocks = 0l;
 	struct cl_limits limits;
+	unsigned long int scanned_blocks = 0l;
 	gint status, fd;
-	const gchar *virus_name = NULL;
 	guint options;
+	const gchar *virus_name = NULL;
 
 	/* Interrupted? */
 	if(*stop_count > 0)
@@ -495,15 +495,22 @@ static gint AVScanOPClamAVScanFile(
 	fd = open((const char *)path, O_RDONLY);
 	if(fd < 0)
 	{
+	    /* Unable to open the file for reading, report error */
 	    const gint error_code = (gint)errno;
 	    PRINT_PROBLEM(path, g_strerror(error_code));
+
+	    /* Unable to open an input file */
 	    return(54);
 	}
 
 	/* Interrupted? */
 	if(*stop_count > 0)
 	{
-	    close(fd);
+	    /* Close the file but discard the return value because we
+	     * are interrupting and thus do not care of buffered
+	     * read()s or write()s
+	     */
+	    (void)close(fd);
 	    return(4);
 	}
 
@@ -546,16 +553,24 @@ static gint AVScanOPClamAVScanFile(
 #endif
 
 	/* Scan this file */
-	status = cl_scandesc(
+	status = (gint)cl_scandesc(
 	    fd,
 	    &virus_name, &scanned_blocks,
 	    d->database,
 	    &limits,
-	    options
+	    (unsigned int)options
 	);
 
 	/* Close the file */
-	close(fd);
+	if(close(fd) != 0)
+	{
+	    /* Unable to close the file, report problem */
+	    const gint error_code = (gint)errno;
+	    PRINT_PROBLEM(path, g_strerror(error_code));
+
+	    /* An error occured while reading an input file */
+	    return(55);
+	}
 
 	/* Count this file as scanned and how much scanned */
 	d->files_scanned++;
@@ -592,9 +607,13 @@ static gint AVScanOPClamAVScanFile(
 	/* Check the scan results */
 
 	/* Got a virus? */
+#if defined(CL_VIRUS)
 	if(status == CL_VIRUS)
+#else
+	if(status == 1)
+#endif
 	{
-	    /* Detected a virus */
+	    /* Detected a virus, print the virus message */
 	    PRINT_INFECTED(path, virus_name);
 
 	    d->infected_files++;	/* Count this infected file */
@@ -602,17 +621,33 @@ static gint AVScanOPClamAVScanFile(
 	    return(1);
 	}
 	/* Clean? */
+#if defined(CL_CLEAN)
+	else if(status == CL_CLEAN)
+#elif defined(CL_SUCCESS)
+	else if(status == CL_SUCCESS)
+#else
 	else if(status == 0)
+#endif
 	{
 	    /* Interrupted? */
 	    if(*stop_count > 0)
 		return(4);
 
+	    /* Print the clean message only if reporting all objects */
 	    if(scanner_opts->flags & SCANNER_FLAG_REPORT_ALL_OBJECTS)
 		PRINT_CLEAN(path);
 
 	    return(0);
 	}
+	/* Interrupted */
+#if defined(CL_BREAK)
+	else if(status == CL_BREAK)
+#else
+	else if(status == 2)
+#endif
+	{
+	    return(4);
+	}
 	/* Other error */
 	else
 	{
@@ -627,142 +662,161 @@ static gint AVScanOPClamAVScanFile(
 	    {
 #ifdef CL_EMAXREC
 	      case CL_EMAXREC:
-		status = 57;
+		status = 57;	/* Scan of object was incomplete because
+				 * it would otherwise exceed a specified
+				 * limit */
 		break;
 #endif
 #ifdef CL_EMAXSIZE
 	      case CL_EMAXSIZE:
-		status = 57;
+		status = 57;	/* Scan of object was incomplete because
+				 * it would otherwise exceed a specified
+				 * limit */
 		break;
 #endif
 #ifdef CL_EMAXFILES
 	      case CL_EMAXFILES:
-		status = 57;
+		status = 57;	/* Scan of object was incomplete because
+				 * it would otherwise exceed a specified
+				 * limit */
 		break;
 #endif
 #ifdef CL_ERAR
 	      case CL_ERAR:
-		status = 59;
+		status = 59;	/* Scanner subsystem or plugin error */
 		break;
 #endif
 #ifdef CL_EZIP
 	      case CL_EZIP:
-		status = 59;
+		status = 59;	/* Scanner subsystem or plugin error */
 		break;
 #endif
 #ifdef CL_EMALFZIP
 	      case CL_EMALFZIP:
-		status = 51;
+		status = 51;	/* An input file has a corrupt format or
+				 * a format not consistent with its
+				 * extension */
 		break;
 #endif
 #ifdef CL_EGZIP
 	      case CL_EGZIP:
-		status = 59;
+		status = 59;	/* Scanner subsystem or plugin error */
 		break;
 #endif
 #ifdef CL_EBZIP
 	      case CL_EBZIP:
-		status = 59;
+		status = 59;	/* Scanner subsystem or plugin error */
 		break;
 #endif
 #ifdef CL_EOLE2
 	      case CL_EOLE2:
-		status = 59;
+		status = 59;	/* Scanner subsystem or plugin error */
 		break;
 #endif
 #ifdef CL_EMSCOMP
 	      case CL_EMSCOMP:
-		status = 59;
+		status = 59;	/* Scanner subsystem or plugin error */
 		break;
 #endif
 #ifdef CL_EMSCAB
 	      case CL_EMSCAB:
-		status = 59;
+		status = 59;	/* Scanner subsystem or plugin error */
 		break;
 #endif
 #ifdef CL_EACCES
 	      case CL_EACCES:
-		status = 55;
+		status = 55;	/* An error occured while reading an input
+				 * file */
 		break;
 #endif
 #ifdef CL_ENULLARG
 	      case CL_ENULLARG:
-		status = 2;
+		status = 2;	/* Invalid value */
 		break;
 #endif
 #ifdef CL_ETMPFILE
 	      case CL_ETMPFILE:
-		status = 3;
+		status = 63;	/* Unable to create a tempory file or
+				 * directory */
 		break;
 #endif
 #ifdef CL_EFSYNC
 	      case CL_EFSYNC:
-		status = 3;
+		status = 3;	/* fsync() failed (systems error) */
 		break;
 #endif
 #ifdef CL_EMEM
 	      case CL_EMEM:
-		status = 3;
+		status = 3;	/* Memory allocation error */
 		break;
 #endif
 #ifdef CL_EOPEN
 	      case CL_EOPEN:
-		status = 54;
+		status = 54;	/* Unable to open an input file */
 		break;
 #endif
 #ifdef CL_EMALFDB
 	      case CL_EMALFDB:
-		status = 50;
+		status = 50;	/* Unable to load or initialize the virus
+                                 * database */
 		break;
 #endif
 #ifdef CL_EPATSHORT
 	      case CL_EPATSHORT:
-		status = 2;
+		status = 2;	/* Pattern too short (invalid value) */
 		break;
 #endif
 #ifdef CL_ETMPDIR
 	      case CL_ETMPDIR:
-		status = 3;
+		status = 63;	/* Unable to create a tempory file or
+				 * directory */
 		break;
 #endif
 #ifdef CL_ECVD
 	      case CL_ECVD:
-		status = 50;
+		status = 50;	/* Unable to load or initialize the virus
+				 * database */
 		break;
 #endif
 #ifdef CL_ECVDEXTR
 	      case CL_ECVDEXTR:
-		status = 50;
+		status = 50;	/* Unable to load or initialize the virus
+				 * database */
 		break;
 #endif
 #ifdef CL_EMD5
 	      case CL_EMD5:
-		status = 50;
+		status = 50;	/* Unable to load or initialize the virus
+				 * database */
 		break;
 #endif
 #ifdef CL_EDSIG
 	      case CL_EDSIG:
-		status = 50;
+		status = 50;	/* Unable to load or initialize the virus
+				 * database */
 		break;
 #endif
 #ifdef CL_EIO
 	      case CL_EIO:
-		status = 3;
+		status = 58;	/* I/O error */
 		break;
 #endif
 #ifdef CL_EFORMAT
 	      case CL_EFORMAT:
-		status = 51;
+		status = 51;	/* An input file has a corrupt format or
+				 * a format not consistent with its
+				 * extension */
 		break;
 #endif
-#ifdef ESUPPORT
-	      case ESUPPORT:
-		status = 60;
+#ifdef CL_ESUPPORT
+	      case CL_ESUPPORT:
+		status = 60;	/* Unsupported file format */
 		break;
 #endif
-#ifdef ELOCKDB
-	      case ELOCKDB:
-		status = 61;
+#ifdef CL_ELOCKDB
+	      case CL_ELOCKDB:
+		status = 61;	/* Unable to lock the virus database
+				 * directory */
 		break;
 #endif
 	      default:
