@@ -792,11 +792,10 @@ char *FGetString(FILE *fp)
 	int c, i = 0, len = 0;
 	char *s = NULL, *s2;
 
-
 	if(fp == NULL)
 	    return(s);
 
-	/* Begin reading string from file */
+	/* Begin reading the string from the file */
 
 	/* Skip initial spaces */
 	c = fgetc(fp);
@@ -806,13 +805,13 @@ char *FGetString(FILE *fp)
 	if(c == EOF)
 	    return(s);
 
-	/* Read string */
+	/* Read the string */
 	while(1)
 	{
 	    /* Need to increase allocation? */
 	    if(i >= len)
 	    {
-		len = MAX(len + 128, i + 1);
+		len = MAX((len + 128), (i + 1));
 		s = (char *)realloc(s, len * sizeof(char));
 		if(s == NULL)
 		{
