@@ -3,6 +3,7 @@
 #include <gdk/gdkprivate.h>
 #if defined(_WIN32)
 # include <gdk/gdkwin32.h>
+# define HAVE_WIN32
 #else
 # include <gdk/gdkx.h>
 # define HAVE_X
@@ -22,12 +23,12 @@ static void GUIImagePixelAnySet(
 );
 
 void GUIImageBufferCopyArea(
-	gint bpp,
+	const gint bpp,
 	const guint8 *src_data,
-	gint src_width, gint src_height, gint src_bpl,
+	const gint src_width, const gint src_height, const gint src_bpl,
 	guint8 *tar_data,
-	gint tar_width, gint tar_height, gint tar_bpl,
-	gint tar_x, gint tar_y,
+	const gint tar_width, const gint tar_height, const gint tar_bpl,
+	const gint tar_x, const gint tar_y,
 	const gboolean blend,
 	gint (*progress_cb)(const gulong, const gulong, gpointer),
 	gpointer progress_data
@@ -42,39 +43,39 @@ void GUIImageBufferResize(
 	gpointer progress_data
 );
 void GUIImageBufferRotateCW90(
-	gint bpp,
+	const gint bpp,
 	const guint8 *src_data,
-	gint src_width, gint src_height, gint src_bpl,
+	const gint src_width, const gint src_height, const gint src_bpl,
 	guint8 *tar_data,
-	gint tar_width, gint tar_height, gint tar_bpl
+	const gint tar_width, const gint tar_height, const gint tar_bpl
 );
 void GUIImageBufferRotateCCW90(
-	gint bpp,
+	const gint bpp,
 	const guint8 *src_data,
-	gint src_width, gint src_height, gint src_bpl,
+	const gint src_width, const gint src_height, const gint src_bpl,
 	guint8 *tar_data,
-	gint tar_width, gint tar_height, gint tar_bpl
+	const gint tar_width, const gint tar_height, const gint tar_bpl
 );
 void GUIImageBufferRotateCW180(
-	gint bpp,
+	const gint bpp,
 	const guint8 *src_data,
-	gint src_width, gint src_height, gint src_bpl,
+	const gint src_width, const gint src_height, const gint src_bpl,
 	guint8 *tar_data,
-	gint tar_width, gint tar_height, gint tar_bpl
+	const gint tar_width, const gint tar_height, const gint tar_bpl
 );
 void GUIImageBufferMirrorH(
-	gint bpp,
+	const gint bpp,
 	const guint8 *src_data,
-	gint src_width, gint src_height, gint src_bpl,
+	const gint src_width, const gint src_height, const gint src_bpl,
 	guint8 *tar_data, 
-	gint tar_width, gint tar_height, gint tar_bpl
+	const gint tar_width, const gint tar_height, const gint tar_bpl
 );
 void GUIImageBufferMirrorV(
-	gint bpp,
+	const gint bpp,
 	const guint8 *src_data,
-	gint src_width, gint src_height, gint src_bpl,
-	guint8 *tar_data, 
-	gint tar_width, gint tar_height, gint tar_bpl
+	const gint src_width, const gint src_height, const gint src_bpl,
+	guint8 *tar_data,
+	const gint tar_width, const gint tar_height, const gint tar_bpl
 );
 
 void GUIImageBufferFlattenWithBG(
@@ -200,18 +201,20 @@ static void GUIImagePixelAnySet(
  *	the target image's pixel.
  */
 void GUIImageBufferCopyArea(
-	gint bpp,
+	const gint bpp,
 	const guint8 *src_data,
-	gint src_width, gint src_height, gint src_bpl,
+	const gint src_width, const gint src_height, const gint src_bpl,
 	guint8 *tar_data,
-	gint tar_width, gint tar_height, gint tar_bpl,
-	gint tar_x, gint tar_y,
+	const gint tar_width, const gint tar_height, const gint tar_bpl,
+	const gint tar_x, const gint tar_y,
 	const gboolean blend,
 	gint (*progress_cb)(const gulong, const gulong, gpointer),
 	gpointer progress_data
 )
 {
-	gint x, y, src_y;
+	gint	x, y, src_y,
+		_src_bpl = src_bpl,
+		_tar_bpl = tar_bpl;
 	const guint8 *src_ptr, *src_end;
 	void (*pixel_op_func)(const gint, guint8 *, const guint8 *);
 
@@ -229,10 +232,10 @@ void GUIImageBufferCopyArea(
 	}
 
 	/* Calculate bytes per line values as needed */
-	if(src_bpl <= 0)
-	    src_bpl = src_width * bpp;
-	if(tar_bpl <= 0)
-	    tar_bpl = tar_width * bpp;
+	if(_src_bpl <= 0)
+	    _src_bpl = src_width * bpp;
+	if(_tar_bpl <= 0)
+	    _tar_bpl = tar_width * bpp;
 
 	/* Determine the pixel operation function */
 	switch(bpp)
@@ -275,7 +278,7 @@ void GUIImageBufferCopyArea(
 	    }
 
 	    x = tar_x;
-	    src_ptr = src_data + (src_y * src_bpl);
+	    src_ptr = src_data + (src_y * _src_bpl);
 	    src_end = src_ptr + (src_width * bpp);
 	    while(src_ptr < src_end)
 	    {
@@ -289,7 +292,7 @@ void GUIImageBufferCopyArea(
 		     */
 		    pixel_op_func(
 			bpp,
-			tar_data + (y * tar_bpl) + (x * bpp),
+			tar_data + (y * _tar_bpl) + (x * bpp),
 			src_ptr
 		    );
 		    src_ptr += bpp;
@@ -600,14 +603,16 @@ void GUIImageBufferResize(
  *	clockwise 90 degrees.
  */
 void GUIImageBufferRotateCW90(
-	gint bpp,
+	const gint bpp,
 	const guint8 *src_data,
-	gint src_width, gint src_height, gint src_bpl,
+	const gint src_width, const gint src_height, const gint src_bpl,
 	guint8 *tar_data,
-	gint tar_width, gint tar_height, gint tar_bpl
+	const gint tar_width, const gint tar_height, const gint tar_bpl
 )
 {
-	gint sx, sy, tx, ty;
+	gint	sx, sy, tx, ty,
+		_src_bpl = src_bpl,
+		_tar_bpl = tar_bpl;
 	const guint8 *src_line;
 
 	if((src_width <= 0) || (src_height <= 0) ||
@@ -622,10 +627,10 @@ void GUIImageBufferRotateCW90(
 	    return;
 
 	/* Calculate bytes per line values as needed */
-	if(src_bpl <= 0)
-	    src_bpl = src_width * bpp;
-	if(tar_bpl <= 0)
-	    tar_bpl = tar_width * bpp;
+	if(_src_bpl <= 0)
+	    _src_bpl = src_width * bpp;
+	if(_tar_bpl <= 0)
+	    _tar_bpl = tar_width * bpp;
 
 	/* Copy/rotate clockwise 90 degrees */
 	for(sy = 0, tx = tar_width - 1;
@@ -633,13 +638,13 @@ void GUIImageBufferRotateCW90(
 	    sy++, tx--
 	)
 	{
-	    src_line = src_data + (sy * src_bpl);
+	    src_line = src_data + (sy * _src_bpl);
 	    for(sx = 0, ty = 0;
 		sx < src_width;
 		sx++, ty++
 	    )
 		memcpy(
-		    tar_data + (ty * tar_bpl) + (tx * bpp),
+		    tar_data + (ty * _tar_bpl) + (tx * bpp),
 		    src_line + (sx * bpp),
 		    bpp
 		);
@@ -651,14 +656,16 @@ void GUIImageBufferRotateCW90(
  *	counter-clockwise 90 degrees.
  */
 void GUIImageBufferRotateCCW90(
-	gint bpp,
+	const gint bpp,
 	const guint8 *src_data,
-	gint src_width, gint src_height, gint src_bpl,
+	const gint src_width, const gint src_height, const gint src_bpl,
 	guint8 *tar_data,
-	gint tar_width, gint tar_height, gint tar_bpl
+	const gint tar_width, const gint tar_height, const gint tar_bpl
 )
 {
-	gint sx, sy, tx, ty;
+	gint	sx, sy, tx, ty,
+		_src_bpl = src_bpl,
+		_tar_bpl = tar_bpl;
 	const guint8 *src_line;
 
 	if((src_width <= 0) || (src_height <= 0) ||
@@ -673,10 +680,10 @@ void GUIImageBufferRotateCCW90(
 	    return;
 
 	/* Calculate bytes per line values as needed */
-	if(src_bpl <= 0)
-	    src_bpl = src_width * bpp;
-	if(tar_bpl <= 0)
-	    tar_bpl = tar_width * bpp;
+	if(_src_bpl <= 0)
+	    _src_bpl = src_width * bpp;
+	if(_tar_bpl <= 0)
+	    _tar_bpl = tar_width * bpp;
 
 	/* Copy/rotate counter-clockwise 90 degrees */
 	for(sy = 0, tx = 0;
@@ -684,13 +691,13 @@ void GUIImageBufferRotateCCW90(
 	    sy++, tx++
 	)
 	{
-	    src_line = src_data + (sy * src_bpl);
+	    src_line = src_data + (sy * _src_bpl);
 	    for(sx = 0, ty = tar_height - 1;
 		sx < src_width;
 		sx++, ty--
 	    )
 		memcpy(
-		    tar_data + (ty * tar_bpl) + (tx * bpp),
+		    tar_data + (ty * _tar_bpl) + (tx * bpp),
 		    src_line + (sx * bpp),
 		    bpp
 		);
@@ -702,14 +709,16 @@ void GUIImageBufferRotateCCW90(
  *	clockwise 180 degrees.
  */
 void GUIImageBufferRotateCW180(
-	gint bpp,
+	const gint bpp,
 	const guint8 *src_data,
-	gint src_width, gint src_height, gint src_bpl,
+	const gint src_width, const gint src_height, const gint src_bpl,
 	guint8 *tar_data,
-	gint tar_width, gint tar_height, gint tar_bpl
+	const gint tar_width, const gint tar_height, const gint tar_bpl
 ) 
 {
-	gint sx, sy, tx, ty;
+	gint	sx, sy, tx, ty,
+		_src_bpl = src_bpl,
+		_tar_bpl = tar_bpl;
 	const guint8 *src_line;
 
 	if((src_width <= 0) || (src_height <= 0) ||
@@ -724,10 +733,10 @@ void GUIImageBufferRotateCW180(
 	    return;
 
 	/* Calculate bytes per line values as needed */
-	if(src_bpl <= 0)
-	    src_bpl = src_width * bpp;
-	if(tar_bpl <= 0)
-	    tar_bpl = tar_width * bpp;
+	if(_src_bpl <= 0)
+	    _src_bpl = src_width * bpp;
+	if(_tar_bpl <= 0)
+	    _tar_bpl = tar_width * bpp;
 
 	/* Copy/rotate clockwise 90 degrees */
 	for(sy = 0, ty = tar_height - 1;
@@ -735,13 +744,13 @@ void GUIImageBufferRotateCW180(
 	    sy++, ty--
 	)
 	{
-	    src_line = src_data + (sy * src_bpl);
+	    src_line = src_data + (sy * _src_bpl);
 	    for(sx = 0, tx = tar_width - 1;
 		sx < src_width;
 		sx++, tx--
 	    )
 		memcpy(
-		    tar_data + (ty * tar_bpl) + (tx * bpp),
+		    tar_data + (ty * _tar_bpl) + (tx * bpp),
 		    src_line + (sx * bpp),
 		    bpp
 		);
@@ -753,14 +762,16 @@ void GUIImageBufferRotateCW180(
  *	horizontally.
  */
 void GUIImageBufferMirrorH(
-	gint bpp,
+	const gint bpp,
 	const guint8 *src_data,
-	gint src_width, gint src_height, gint src_bpl,
+	const gint src_width, const gint src_height, const gint src_bpl,
 	guint8 *tar_data,
-	gint tar_width, gint tar_height, gint tar_bpl
+	const gint tar_width, const gint tar_height, const gint tar_bpl
 )
 {
-	gint sx, sy, tx, ty;
+	gint	sx, sy, tx, ty,
+		_src_bpl = src_bpl,
+		_tar_bpl = tar_bpl;
 	const guint8 *src_line;
 
 	if((src_width <= 0) || (src_height <= 0) ||
@@ -775,10 +786,10 @@ void GUIImageBufferMirrorH(
 	    return;
 
 	/* Calculate bytes per line values as needed */
-	if(src_bpl <= 0)
-	    src_bpl = src_width * bpp;
-	if(tar_bpl <= 0)
-	    tar_bpl = tar_width * bpp;
+	if(_src_bpl <= 0)
+	    _src_bpl = src_width * bpp;
+	if(_tar_bpl <= 0)
+	    _tar_bpl = tar_width * bpp;
 
 	/* Copy/mirror horizontally */
 	for(sy = 0, ty = 0;
@@ -786,13 +797,13 @@ void GUIImageBufferMirrorH(
 	    sy++, ty++
 	)
 	{
-	    src_line = src_data + (sy * src_bpl);
+	    src_line = src_data + (sy * _src_bpl);
 	    for(sx = 0, tx = tar_width - 1;
 		sx < src_width;
 		sx++, tx--
 	    )
 		memcpy(
-		    tar_data + (ty * tar_bpl) + (tx * bpp),
+		    tar_data + (ty * _tar_bpl) + (tx * bpp),
 		    src_line + (sx * bpp),
 		    bpp
 		);
@@ -804,14 +815,16 @@ void GUIImageBufferMirrorH(
  *	vertically.
  */
 void GUIImageBufferMirrorV(
-	gint bpp,
+	const gint bpp,
 	const guint8 *src_data,
-	gint src_width, gint src_height, gint src_bpl,
+	const gint src_width, const gint src_height, const gint src_bpl,
 	guint8 *tar_data,
-	gint tar_width, gint tar_height, gint tar_bpl
+	const gint tar_width, const gint tar_height, const gint tar_bpl
 )
 {
-	gint sx, sy, tx, ty;
+	gint	sx, sy, tx, ty,
+		_src_bpl = src_bpl,
+		_tar_bpl = tar_bpl;
 	const guint8 *src_line;
 
 	if((src_width <= 0) || (src_height <= 0) ||
@@ -826,10 +839,10 @@ void GUIImageBufferMirrorV(
 	    return;
 
 	/* Calculate bytes per line values as needed */
-	if(src_bpl <= 0)
-	    src_bpl = src_width * bpp;
-	if(tar_bpl <= 0)
-	    tar_bpl = tar_width * bpp;
+	if(_src_bpl <= 0)
+	    _src_bpl = src_width * bpp;
+	if(_tar_bpl <= 0)
+	    _tar_bpl = tar_width * bpp;
 
 	/* Copy/mirror horizontally */
 	for(sy = 0, ty = tar_height - 1;
@@ -837,13 +850,13 @@ void GUIImageBufferMirrorV(
 	    sy++, ty--
 	)
 	{
-	    src_line = src_data + (sy * src_bpl);
+	    src_line = src_data + (sy * _src_bpl);
 	    for(sx = 0, tx = 0;
 		sx < src_width;
 		sx++, tx++
 	    )
 		memcpy(
-		    tar_data + (ty * tar_bpl) + (tx * bpp),
+		    tar_data + (ty * _tar_bpl) + (tx * bpp),
 		    src_line + (sx * bpp),
 		    bpp
 		);
@@ -981,10 +994,18 @@ void GUIImageBufferFlattenWithBG(
 
 
 /*
- *	Gets a RGB image buffer from the specified drawable with the
- *	specified rectangular area.
+ *	Gets the RGB image data from a GdkDrawable.
  *
- *	If rect is NULL then the entire drawable is obtained.
+ *	The drawable specifies the GdkDrawable.
+ *
+ *	The rect specifies the area within the GdkDrawable. If rect
+ *	is NULL then the entire GdkDrawable is obtained.
+ *
+ *	The width_rtn, height_rtn, and bpl_rtn specifies the
+ *	return values for the image data.
+ *
+ *	Returns a dynamically allocated copy of the image data or NULL
+ *	on error.
  */
 guint8 *GUIGetRGBImage(
 	GdkDrawable *drawable, 
@@ -992,15 +1013,18 @@ guint8 *GUIGetRGBImage(
 	gint *width_rtn, gint *height_rtn, gint *bpl_rtn  
 )
 {
-#if defined(__GDK_X_H__)
+#if defined(HAVE_X)
 	gint width, height, src_bpp, src_bpl, tar_bpp, tar_bpl;
 	const guint8 *src_data;
 	guint8 *tar_data;
 	Display *xdpy;
+	Window xwin;
 	XImage *ximg;
 	GdkRectangle lrect;
-	GdkWindowPrivate *private = (GdkWindowPrivate *)drawable;
-	Window xwin = (private != NULL) ? private->xwindow : None;
+	GdkVisualType visual_type;
+	GdkVisual *visual;
+	GdkColormap *cmap;
+	GdkWindowPrivate *private;
 
 	if(width_rtn != NULL)
 	    *width_rtn = 0;
@@ -1009,21 +1033,30 @@ guint8 *GUIGetRGBImage(
 	if(bpl_rtn != NULL)
 	    *bpl_rtn = 0;
 
-	if(xwin == None)
+	if(drawable == NULL)
 	    return(NULL);
 
+	private = (GdkWindowPrivate *)drawable;
 	xdpy = private->xdisplay;
-	if(xdpy == NULL)
+	xwin = private->xwindow;
+	if((xdpy == NULL) || (xwin == None))
 	    return(NULL);
 
-	/* If no rectangle is specified then set rectangle to cover the
-	 * entire drawable
+	cmap = private->colormap;
+	visual = (cmap != NULL) ? gdk_colormap_get_visual(cmap) : NULL;
+	if(visual != NULL)
+	    visual_type = visual->type;
+	else
+	    visual_type = gdk_visual_get_best_type();
+
+	/* If no rectangle was specified then set the rectangle to
+	 * cover the entire drawable
 	 */
 	if(rect == NULL)
 	{
 	    rect = &lrect;
-	    lrect.x = private->x;
-	    lrect.y = private->y;
+	    lrect.x = 0;
+	    lrect.y = 0;
 	    lrect.width = private->width;
 	    lrect.height = private->height;
 	}
@@ -1039,14 +1072,16 @@ guint8 *GUIGetRGBImage(
 	    AllPlanes,
 	    ZPixmap
 	);
-	if((ximg != NULL) ? (ximg->data == NULL) : TRUE)
+	if(ximg == NULL)
+	    return(NULL);
+
+	if(ximg->data == NULL)
 	{
-	    if(ximg != NULL)
-		XDestroyImage(ximg);
+	    XDestroyImage(ximg);
 	    return(NULL);
 	}
 
-	/* Get values from XImage */
+	/* Get the values from the XImage */
 	width = ximg->width;
 	height = ximg->height;
 	src_bpl = ximg->bytes_per_line;
@@ -1067,38 +1102,94 @@ guint8 *GUIGetRGBImage(
 	 */
 	if(ximg->depth == 8)
 	{
-	    gint xoffset_bytes, x, y;
 	    const gint	r_div = 7,
 			g_div = 7,
 			b_div = 3;
-	    guint src_v;
+	    gint xoffset_bytes, x, y;
+	    guint32 src_v;
 	    const guint8 *src_ptr;
 	    guint8 *tar_ptr;
+	    GdkColor *c;
 
 	    src_bpp = 1;
 	    xoffset_bytes = ximg->xoffset * src_bpp;
 
-	    for(y = 0; y < height; y++)
+	    switch(visual_type)
 	    {
-		src_ptr = (const guint8 *)(
-		    src_data + (y * src_bpl) + xoffset_bytes
-		);
-		tar_ptr = tar_data + (y * tar_bpl);
-
-		for(x = 0; x < width; x++)
+	      case GDK_VISUAL_STATIC_GRAY:
+	      case GDK_VISUAL_GRAYSCALE:
+		for(y = 0; y < height; y++)
 		{
-		    /* 8 Bits Format: rrrgggbb */
-		    src_v = (guint)*src_ptr++;
-		    *tar_ptr++ = (guint8)(
-		((src_v & 0xE0) >> 5) * 0xff / r_div  
-		    );
-		    *tar_ptr++ = (guint8)(
-		((src_v & 0x1C) >> 2) * 0xff / g_div
-		    );
-		    *tar_ptr++ = (guint8)(
-		((src_v & 0x03) >> 0) * 0xff / b_div
+		    src_ptr = (const guint8 *)(
+			src_data + (y * src_bpl) + xoffset_bytes
 		    );
+		    tar_ptr = tar_data + (y * tar_bpl);
+
+		    for(x = 0; x < width; x++)
+		    {
+			*tar_ptr++ = *src_ptr;
+			*tar_ptr++ = *src_ptr;
+			*tar_ptr++ = *src_ptr++;
+		    }
 		}
+		break;
+
+	      case GDK_VISUAL_STATIC_COLOR:
+	      case GDK_VISUAL_PSEUDO_COLOR:
+		if(cmap == NULL)
+		{
+		    g_free(tar_data);
+		    XDestroyImage(ximg);
+		    return(NULL);
+		}
+		if((cmap->colors == NULL) || (cmap->size <= 0))
+		{
+		    g_free(tar_data);
+		    XDestroyImage(ximg);
+		    return(NULL);
+		}
+		for(y = 0; y < height; y++)
+		{
+		    src_ptr = (const guint8 *)(
+			src_data + (y * src_bpl) + xoffset_bytes
+		    );
+		    tar_ptr = tar_data + (y * tar_bpl);
+
+		    for(x = 0; x < width; x++)
+		    {
+			c = &cmap->colors[*src_ptr];
+			src_ptr++;
+			*tar_ptr++ = (guint8)(c->red >> 8);
+			*tar_ptr++ = (guint8)(c->green >> 8);
+			*tar_ptr++ = (guint8)(c->blue >> 8);
+		    }
+		}
+		break;
+
+	      default:		/* GDK_VISUAL_TRUE_COLOR */
+		for(y = 0; y < height; y++)
+		{
+		    src_ptr = (const guint8 *)(
+			src_data + (y * src_bpl) + xoffset_bytes
+		    );
+		    tar_ptr = tar_data + (y * tar_bpl);
+
+		    for(x = 0; x < width; x++)
+		    {
+			/* 8 Bits Format: rrrgggbb */
+			src_v = (guint32)*src_ptr++;
+			*tar_ptr++ = (guint8)(
+		((src_v & 0xE0) >> 5) * 0xff / r_div  
+			);
+			*tar_ptr++ = (guint8)(
+		((src_v & 0x1C) >> 2) * 0xff / g_div
+			);
+			*tar_ptr++ = (guint8)(
+		((src_v & 0x03) >> 0) * 0xff / b_div
+			);
+		    }
+		}
+		break;
 	    }
 	}
 	else if(ximg->depth == 15)
@@ -1107,6 +1198,7 @@ guint8 *GUIGetRGBImage(
 	    const gint  r_div = 31,
 			g_div = 31,
 			b_div = 31;
+	    guint16 v16;
 	    const guint16 *src_ptr;
 	    guint8 *tar_ptr;
 
@@ -1122,18 +1214,18 @@ guint8 *GUIGetRGBImage(
 
 		for(x = 0; x < width; x++)
 		{
-		    /* 16 Bits Format: arrrrrgg gggbbbbb */
-		    *tar_ptr++ = (guint8)(
-		((((guint)*src_ptr) & 0x7C00) >> 10) * 0xff / r_div
-		    );
-		    *tar_ptr++ = (guint8)(
-		((((guint)*src_ptr) & 0x03E0) >> 5) * 0xff / g_div
-		    );
-		    *tar_ptr++ = (guint8)(
-		((((guint)*src_ptr) & 0x001F) >> 0) * 0xff / b_div
-		    );
+		    /* 15 Bits Format: arrrrrgg gggbbbbb */
+		    v16 = *src_ptr++;
 
-		    src_ptr++;
+		    *tar_ptr++ = (guint8)(
+		(guint32)((v16 & 0x7C00) >> 10) * 0xFF / r_div
+		    );
+		    *tar_ptr++ = (guint8)(
+		(guint32)((v16 & 0x03E0) >> 5) * 0xFF / g_div
+		    );
+		    *tar_ptr++ = (guint8)(
+		(guint32)((v16 & 0x001F) >> 0) * 0xFF / b_div
+		    );
 		}
 	    }
 	}
@@ -1143,6 +1235,7 @@ guint8 *GUIGetRGBImage(
 	    const gint  r_div = 31,
 			g_div = 63,
 			b_div = 31;
+	    guint16 v16;
 	    const guint16 *src_ptr;
 	    guint8 *tar_ptr;
 
@@ -1159,17 +1252,17 @@ guint8 *GUIGetRGBImage(
 		for(x = 0; x < width; x++)
 		{
 		    /* 16 Bits Format: rrrrrggg gggbbbbb */
-		    *tar_ptr++ = (guint8)(
-		((((guint)*src_ptr) & 0xF800) >> 11) * 0xff / r_div
-		    );
-		    *tar_ptr++ = (guint8)(
-		((((guint)*src_ptr) & 0x07E0) >> 5) * 0xff / g_div
-		    );
-		    *tar_ptr++ = (guint8)(
-		((((guint)*src_ptr) & 0x001F) >> 0) * 0xff / b_div
-		    );
+		    v16 = *src_ptr++;
 
-		    src_ptr++;
+		    *tar_ptr++ = (guint8)(
+		(guint32)((v16 & 0xF800) >> 11) * 0xFF / r_div
+		    );
+		    *tar_ptr++ = (guint8)(
+		(guint32)((v16 & 0x07E0) >> 5) * 0xFF / g_div
+		    );
+		    *tar_ptr++ = (guint8)(
+		(guint32)((v16 & 0x001F) >> 0) * 0xFF / b_div
+		    );
 		}
 	    }
 	}
@@ -1250,10 +1343,18 @@ guint8 *GUIGetRGBImage(
 }
 
 /*
- *	Gets a RGB image buffer from the specified drawable with the 
- *	specified rectangular area.
+ *	Gets the RGBA image data from a GdkDrawable.
  *
- *	If rect is NULL then the entire drawable is obtained.
+ *	The drawable specifies the GdkDrawable.
+ *
+ *	The rect specifies the area within the GdkDrawable. If rect
+ *	is NULL then the entire GdkDrawable is obtained.
+ *
+ *	The width_rtn, height_rtn, and bpl_rtn specifies the
+ *	return values for the image data.
+ *
+ *	Returns a dynamically allocated copy of the image data or NULL
+ *	on error.
  */
 guint8 *GUIGetRGBAImage(
 	GdkDrawable *drawable,
@@ -1261,15 +1362,18 @@ guint8 *GUIGetRGBAImage(
 	gint *width_rtn, gint *height_rtn, gint *bpl_rtn  
 )
 {
-#if defined(__GDK_X_H__)
+#if defined(HAVE_X)
 	gint width, height, src_bpp, src_bpl, tar_bpp, tar_bpl;
 	const guint8 *src_data;
 	guint8 *tar_data;
 	Display *xdpy;
+	Window xwin;
 	XImage *ximg;
 	GdkRectangle lrect;
-	GdkWindowPrivate *private = (GdkWindowPrivate *)drawable;
-	Window xwin = (private != NULL) ? private->xwindow : None;
+	GdkVisualType visual_type;
+	GdkVisual *visual;
+	GdkColormap *cmap;
+	GdkWindowPrivate *private;
 
 	if(width_rtn != NULL)
 	    *width_rtn = 0;
@@ -1278,21 +1382,30 @@ guint8 *GUIGetRGBAImage(
 	if(bpl_rtn != NULL)
 	    *bpl_rtn = 0;
 
-	if(xwin == None)
+	if(drawable == NULL)
 	    return(NULL);
 
+	private = (GdkWindowPrivate *)drawable;
 	xdpy = private->xdisplay;
-	if(xdpy == NULL)
+	xwin = private->xwindow;
+	if((xdpy == NULL) || (xwin == None))
 	    return(NULL);
 
-	/* If no rectangle is specified then set rectangle to cover the
-	 * entire drawable
+	cmap = private->colormap;
+	visual = (cmap != NULL) ? gdk_colormap_get_visual(cmap) : NULL;
+	if(visual != NULL)
+	    visual_type = visual->type;
+	else
+	    visual_type = gdk_visual_get_best_type();
+
+	/* If no rectangle was specified then set the rectangle to
+	 * cover the entire drawable
 	 */
 	if(rect == NULL)
 	{
 	    rect = &lrect;
-	    lrect.x = private->x;
-	    lrect.y = private->y;
+	    lrect.x = 0;
+	    lrect.y = 0;
 	    lrect.width = private->width;
 	    lrect.height = private->height;
 	}
@@ -1308,21 +1421,23 @@ guint8 *GUIGetRGBAImage(
 	    AllPlanes,
 	    ZPixmap
 	);
-	if((ximg != NULL) ? (ximg->data == NULL) : TRUE)
+	if(ximg == NULL)
+	    return(NULL);
+
+	if(ximg->data == NULL)
 	{
-	    if(ximg != NULL)
-		XDestroyImage(ximg);
+	    XDestroyImage(ximg);
 	    return(NULL);
 	}
 
-	/* Get values from XImage */
+	/* Get the values from the XImage */
 	width = ximg->width;
 	height = ximg->height;
 	src_bpl = ximg->bytes_per_line;
 	src_data = (const guint8 *)ximg->data;
 
 	/* Allocate the target RGBA image data */
-	tar_bpp = 4;
+	tar_bpp = 4 * sizeof(guint8);
 	tar_bpl = width * tar_bpp;
 	tar_data = (guint8 *)g_malloc(tar_bpl * height);
 	if(tar_data == NULL)
@@ -1332,18 +1447,14 @@ guint8 *GUIGetRGBAImage(
 	}
 
 	/* Begin copying the XImage data to the return data */
-	if(ximg->depth == 8)
+	if(ximg->depth == 1)
 	{
-	    gint xoffset_bytes, x, y;
-	    const gint	r_div = 7,
-			g_div = 7,
-			b_div = 3;
-	    guint src_v;
+	    gint x, y, xoffset_bytes;
 	    const guint8 *src_ptr;
 	    guint8 *tar_ptr;
 
-	    src_bpp = 1;
-	    xoffset_bytes = ximg->xoffset * src_bpp;
+            src_bpp = 1;
+            xoffset_bytes = ximg->xoffset * src_bpp;
 
 	    for(y = 0; y < height; y++)
 	    {
@@ -1354,27 +1465,125 @@ guint8 *GUIGetRGBAImage(
 
 		for(x = 0; x < width; x++)
 		{
-		    /* 8 Bits Format: rrrgggbb */
-		    src_v = (guint)*src_ptr++;
-		    *tar_ptr++ = (guint8)(
-		((src_v & 0xE0) >> 5) * 0xff / r_div
-		    );
-		    *tar_ptr++ = (guint8)(
-		((src_v & 0x1C) >> 2) * 0xff / g_div
-		    );
-		    *tar_ptr++ = (guint8)(
-		((src_v & 0x03) >> 0) * 0xff / b_div
-		    );
-		    *tar_ptr++ = 0xff;
+		    if(src_ptr[x / 8] & (1 << (x % 8)))
+		    {
+			*tar_ptr++ = 0xff;
+			*tar_ptr++ = 0xff;
+			*tar_ptr++ = 0xff;
+			*tar_ptr++ = 0xff;
+		    }
+		    else
+		    {
+			*tar_ptr++ = 0x00;
+			*tar_ptr++ = 0x00;
+			*tar_ptr++ = 0x00;
+			*tar_ptr++ = 0x00;
+		    }
 		}
 	    }
 	}
+	else if(ximg->depth == 8)
+	{
+	    const gint	r_div = 7,
+			g_div = 7,
+			b_div = 3;
+	    gint xoffset_bytes, x, y;
+	    guint32 src_v;
+	    const guint8 *src_ptr;
+	    guint8 *tar_ptr;
+	    GdkColor *c;
+
+	    src_bpp = 1;
+	    xoffset_bytes = ximg->xoffset * src_bpp;
+
+	    switch(visual_type)
+	    {
+	      case GDK_VISUAL_STATIC_GRAY:
+	      case GDK_VISUAL_GRAYSCALE:
+		for(y = 0; y < height; y++)
+		{
+		    src_ptr = (const guint8 *)(
+			src_data + (y * src_bpl) + xoffset_bytes
+		    );
+		    tar_ptr = tar_data + (y * tar_bpl);
+
+		    for(x = 0; x < width; x++)
+		    {
+			*tar_ptr++ = *src_ptr;
+			*tar_ptr++ = *src_ptr;
+			*tar_ptr++ = *src_ptr++;
+			*tar_ptr++ = 0xff;
+		    }
+		}
+		break;
+
+	      case GDK_VISUAL_STATIC_COLOR:
+	      case GDK_VISUAL_PSEUDO_COLOR:
+		if(cmap == NULL)
+		{
+		    g_free(tar_data);
+		    XDestroyImage(ximg);
+		    return(NULL);
+		}
+		if((cmap->colors == NULL) || (cmap->size <= 0))
+		{
+		    g_free(tar_data);
+		    XDestroyImage(ximg);
+		    return(NULL);
+		}
+		for(y = 0; y < height; y++)
+		{
+		    src_ptr = (const guint8 *)(
+			src_data + (y * src_bpl) + xoffset_bytes
+		    );
+		    tar_ptr = tar_data + (y * tar_bpl);
+
+		    for(x = 0; x < width; x++)
+		    {
+			c = &cmap->colors[*src_ptr];
+			src_ptr++;
+			*tar_ptr++ = (guint8)(c->red >> 8);
+			*tar_ptr++ = (guint8)(c->green >> 8);
+			*tar_ptr++ = (guint8)(c->blue >> 8);
+			*tar_ptr++ = 0xff;
+		    }
+		}
+		break;
+
+	      default:		/* GDK_VISUAL_TRUE_COLOR */
+		for(y = 0; y < height; y++)
+		{
+		    src_ptr = (const guint8 *)(
+			src_data + (y * src_bpl) + xoffset_bytes
+		    );
+		    tar_ptr = tar_data + (y * tar_bpl);
+
+		    for(x = 0; x < width; x++)
+		    {
+			/* 8 Bits Format: rrrgggbb */
+			src_v = (guint32)*src_ptr++;
+			*tar_ptr++ = (guint8)(
+		((src_v & 0xE0) >> 5) * 0xff / r_div  
+			);
+			*tar_ptr++ = (guint8)(
+		((src_v & 0x1C) >> 2) * 0xff / g_div
+			);
+			*tar_ptr++ = (guint8)(
+		((src_v & 0x03) >> 0) * 0xff / b_div
+			);
+			*tar_ptr++ = 0xff;
+		    }
+		}
+		break;
+	    }
+	}
 	else if(ximg->depth == 15)
 	{
 	    gint xoffset_bytes, x, y;
 	    const gint	r_div = 31,
 			g_div = 31,
 			b_div = 31;
+	    guint16 v16;
 	    const guint16 *src_ptr;
 	    guint8 *tar_ptr;
 
@@ -1390,23 +1599,22 @@ guint8 *GUIGetRGBAImage(
 
 		for(x = 0; x < width; x++)
 		{
-		    /* 16 Bits Format: arrrrrgg gggbbbbb */
+		    /* 15 Bits Format: arrrrrgg gggbbbbb */
+		    v16 = *src_ptr++;
+
 		    *tar_ptr++ = (guint8)(
-		((((guint)*src_ptr) & 0x7C00) >> 10) * 0xff / r_div
+		(guint32)((v16 & 0x7C00) >> 10) * 0xFF / r_div
 		    );
 		    *tar_ptr++ = (guint8)(
-		((((guint)*src_ptr) & 0x03E0) >> 5) * 0xff / g_div
+		(guint32)((v16 & 0x03E0) >> 5) * 0xFF / g_div
 		    );
 		    *tar_ptr++ = (guint8)(
-		((((guint)*src_ptr) & 0x001F) >> 0) * 0xff / b_div
+		(guint32)((v16 & 0x001F) >> 0) * 0xFF / b_div
 		    );
 /* Alpha channel may not be defined
-		    *tar_ptr++ = (((guint)*src_ptr) & (1 << 15)) ?
-			0xff : 0x00;
+		    *tar_ptr++ = (v16 & (1 << 15)) ? 0xff : 0x00;
  */
 		    *tar_ptr++ = 0xff;
-
-		    src_ptr++;
 		}
 	    }
 	}
@@ -1416,6 +1624,7 @@ guint8 *GUIGetRGBAImage(
 	    const gint  r_div = 31,
 			g_div = 63,
 			b_div = 31;
+	    guint16 v16;
 	    const guint16 *src_ptr;
 	    guint8 *tar_ptr;
 
@@ -1432,18 +1641,18 @@ guint8 *GUIGetRGBAImage(
 		for(x = 0; x < width; x++)
 		{
 		    /* 16 Bits Format: rrrrrggg gggbbbbb */
+		    v16 = *src_ptr++;
+
 		    *tar_ptr++ = (guint8)(
-		((((guint)*src_ptr) & 0xF800) >> 11) * 0xff / r_div
+		(guint32)((v16 & 0xF800) >> 11) * 0xff / r_div
 		    );
 		    *tar_ptr++ = (guint8)(
-		((((guint)*src_ptr) & 0x07E0) >> 5) * 0xff / g_div
+		(guint32)((v16 & 0x07E0) >> 5) * 0xff / g_div
 		    );
 		    *tar_ptr++ = (guint8)(
-		((((guint)*src_ptr) & 0x001F) >> 0) * 0xff / b_div
+		(guint32)((v16 & 0x001F) >> 0) * 0xff / b_div
 		    );
 		    *tar_ptr++ = 0xff;
-
-		    src_ptr++;
 		}
 	    }
 	}	    
