@@ -4,16 +4,19 @@
 #include <signal.h>
 #include <gtk/gtk.h>
 #if defined(_WIN32)
+# include <gdk/gdkprivate.h>
 # include <gdk/gdkwin32.h>
-# define HAVE_WIN32
 #else
 # include <gdk/gdkx.h>
-# define HAVE_X
 #endif
 #ifdef HAVE_EDV2
 #include <endeavour2.h>
 #endif
-#include <unistd.h>
+#if defined(_WIN32)
+# include <windows.h>
+#else
+# include <unistd.h>
+#endif
 
 #include "guiutils.h"
 #include "fprompt.h"
@@ -44,6 +47,18 @@
 static void MainSignalCB(int s);
 static gint MainTOCB(gpointer data);
 
+static void MainFileSelectorCreatedCB(
+	const gchar *path, gpointer data
+);
+static void MainFileSelectorModifiedCB(
+	const gchar *old_path,
+	const gchar *new_path,
+	gpointer data
+);
+static void MainFileSelectorDeletedCB(
+	const gchar *path, gpointer data
+);
+
 static cfg_item_struct *MainCfgListNew(void);
 
 win_struct *MainNewAVScan(core_struct *core, gint argc, gchar **argv);
@@ -172,6 +187,51 @@ static gint MainTOCB(gpointer data)
 }
 
 
+/*
+ *	File selector created callback.
+ */
+static void MainFileSelectorCreatedCB(
+	const gchar *path, gpointer data
+)
+{
+	core_struct *core = CORE(data);
+#ifdef HAVE_EDV2
+	EDVNotifyQueueObjectAdded(core->edv_ctx, path);
+	EDVContextFlush(core->edv_ctx);
+#endif
+}
+
+/*
+ *	File selector changed callback.
+ */
+static void MainFileSelectorModifiedCB(
+	const gchar *old_path,
+	const gchar *new_path,
+	gpointer data
+)
+{
+	core_struct *core = CORE(data);
+#ifdef HAVE_EDV2
+	EDVNotifyQueueObjectModified(core->edv_ctx, old_path, new_path);
+	EDVContextFlush(core->edv_ctx);
+#endif
+}
+
+/*
+ *	File selector deleted callback.
+ */
+static void MainFileSelectorDeletedCB(
+	const gchar *path, gpointer data
+)
+{
+	core_struct *core = CORE(data);
+#ifdef HAVE_EDV2
+	EDVNotifyQueueObjectRemoved(core->edv_ctx, path);
+	EDVContextFlush(core->edv_ctx);
+#endif
+}
+
+
 /*
  *	Creates a new default Configuration List.
  */
@@ -179,12 +239,9 @@ static cfg_item_struct *MainCfgListNew(void)
 {
 	const cfg_item_struct src_cfg_list[] = CFG_LIST;
 	cfg_item_struct *cfg_list = CFGItemListCopyList(src_cfg_list);
-	gchar cwd[PATH_MAX];
-
-	if(getcwd(cwd, sizeof(cwd)) != NULL)
-	    cwd[sizeof(cwd) - 1] = '\0';
-	else
-	    *cwd = '\0';
+	const gchar *cwd = g_get_current_dir();
+	if(cwd == NULL)
+	   cwd = "/";
 
 	CFGItemListSetValueI(
 	    cfg_list, CFG_PARM_VERSION_MAJOR,
@@ -776,7 +833,7 @@ AntiVirus Engine: %s\n",
 #endif
 
 	core->target_scan_item_atom = gdk_atom_intern(
-	    DND_TARGET_SCAN_ITEM,
+	    AVSCAN_DND_TARGET_SCAN_ITEM,
 	    FALSE
 	);
 
@@ -923,6 +980,16 @@ AntiVirus Engine: %s\n",
 	CFGFileOpen(path, cfg_list);
 	g_free(path);
 
+	/* Set the file selector callbacks */
+	FileBrowserSetObjectCreatedCB(
+	    MainFileSelectorCreatedCB, core
+	);
+	FileBrowserSetObjectModifiedCB(
+	    MainFileSelectorModifiedCB, core
+	);
+	FileBrowserSetObjectDeletedCB(
+	    MainFileSelectorDeletedCB, core
+	);
 
 	/* Create the AVScan window */
 	win = MainNewAVScan(core, argc, argv);
@@ -937,6 +1004,10 @@ AntiVirus Engine: %s\n",
  }							\
 }
 
+	    /* Reset the current location and scan options */
+	    WinSetCurrentLocation(win, "");
+	    WinSetCurrentOptions(win, 0);
+
 	    /* Parse the arguments */
 	    for(i = 1; i < argc; i++)
 	    {
@@ -975,7 +1046,7 @@ AntiVirus Engine: %s\n",
 		)
 		{
 		    gtk_toggle_button_set_active(
-			GTK_TOGGLE_BUTTON(win->recursive_check),
+			GTK_TOGGLE_BUTTON(win->scan_recursive_check),
 			TRUE 
 		    );
 		}
@@ -986,7 +1057,7 @@ AntiVirus Engine: %s\n",
 		)
 		{
 		    gtk_toggle_button_set_active(
-			GTK_TOGGLE_BUTTON(win->executables_only_check),
+			GTK_TOGGLE_BUTTON(win->scan_executables_only_check),
 			TRUE
 		    );
 		}
@@ -997,7 +1068,7 @@ AntiVirus Engine: %s\n",
 		)
 		{
 		    gtk_toggle_button_set_active(
-			GTK_TOGGLE_BUTTON(win->ignore_links_check),
+			GTK_TOGGLE_BUTTON(win->scan_ignore_links_check),
 			TRUE
 		    );
 		}
@@ -1236,26 +1307,16 @@ AntiVirus Engine: %s\n",
 	    /* Need to start scan on startup? */
 	    if(paths_list != NULL)
 	    {
-		gchar *s, *location = STRDUP("");
-		GList *glist;
-		GtkEntry *entry = GTK_ENTRY(win->location_entry);
+		WinScanProcessStart(
+		    win,
+		    NULL,		/* Use the virus database path
+					 * specified in the configuration */
+		    paths_list,
+		    WinGetCurrentOptions(win)
+		);
 
-		for(glist = paths_list; glist != NULL; glist = g_list_next(glist))
-		{
-		    s = g_strconcat(
-			location,
-			(const gchar *)glist->data,
-			(g_list_next(glist) != NULL) ? "," : "",
-			NULL
-		    );
-		    g_free(location);
-		    location = s;
-		}
-		gtk_entry_set_text(entry, location);
-		gtk_entry_set_position(entry, -1);
-		g_free(location);
-
-		WinStartCB(win->start_btn, win);
+		/* Switch to the results page */
+		WinSwitchPage(win, WIN_PAGE_NUM_RESULTS);
 	    }
 
 	    DELETE_LOCALS
