@@ -14,7 +14,12 @@ typedef enum {
 
 	AVSCAN_OPT_RECURSIVE			= (1 << 0),
 	AVSCAN_OPT_EXECUTABLES_ONLY		= (1 << 1),
-	AVSCAN_OPT_IGNORE_LINKS			= (1 << 2)
+	AVSCAN_OPT_IGNORE_LINKS			= (1 << 2),
+
+	/* The following flags are for objects stored on the
+	 * Results List
+	 */
+	AVSCAN_OPT_INFECTED			= (1 << 8)
 
 } avscan_options;
 
@@ -37,14 +42,14 @@ extern obj_struct *ObjNew(void);
 extern obj_struct *ObjCopy(const obj_struct *obj);
 extern void ObjDelete(obj_struct *obj);
 
-extern GList *ObjDDEBufferParse(const guint8 *buf, gint buf_len);
+extern GList *ObjDDEBufferParse(const guint8 *buf, const gint buf_len);
 extern guint8 *ObjDDEBufferAppend(
-        guint8 *buf, gint *buf_len,
+        guint8 *buf, gint *buf_len_rtn,
         const obj_struct *obj  
 );
-extern GList *ObjDDEBufferParsePath(const guint8 *buf, gint buf_len);
+extern GList *ObjDDEBufferParsePath(const guint8 *buf, const gint buf_len);
 extern guint8 *ObjDDEBufferAppendPath(
-        guint8 *buf, gint *buf_len, 
+        guint8 *buf, gint *buf_len_rtn, 
         const obj_struct *obj
 );
 
