@@ -18,7 +18,7 @@
 #include "images/icon_wand_32x32.xpm"
 #include "images/icon_search_32x32.xpm"
 #include "images/icon_security_32x32.xpm"
-#include "images/icon_print_32x32.xpm"
+#include "images/icon_print2_32x32.xpm"
 #include "images/icon_sound_32x32.xpm"
 #include "images/icon_bulb_32x32.xpm"
 #include "images/icon_power_32x32.xpm"
@@ -27,10 +27,10 @@
 #else
 # include "images/icon_linux_32x32.xpm"
 #endif
-#include "images/icon_terminal_32x32.xpm"
+#include "images/icon_terminal2_32x32.xpm"
 #include "images/icon_tuning_32x32.xpm"
 #include "images/icon_tools_32x32.xpm"
-#include "images/icon_monitor_32x32.xpm"
+#include "images/icon_monitor2_32x32.xpm"
 #include "images/icon_clipboard_32x32.xpm"
 #include "images/icon_clipboard_empty_32x32.xpm"
 #include "images/icon_edit_32x32.xpm"
@@ -433,23 +433,26 @@ static gint PDialogEntryCompletePathKeyCB(
 
 	    if(press)
 	    {
-		gchar *s = STRDUP(gtk_entry_get_text(entry));
-		if(s != NULL)
+		gchar *path = STRDUP(gtk_entry_get_text(entry));
+		if(path != NULL)
 		{
+		    gchar *prev_path = STRDUP(path);
 		    gint status;
 
-		    s = CompletePath(s, &status);
-		    gtk_entry_set_text(entry, (s != NULL) ? s : "");
+		    /* Complete the path */
+		    path = (gchar *)CompletePath((char *)path, &status);
+		    gtk_entry_set_text(entry, (path != NULL) ? path : "");
 		    gtk_entry_set_position(entry, -1);
-		    g_free(s);
 
-		    switch(status)
+		    /* Beep if there was no change in the path */
+		    if((prev_path != NULL) && (path != NULL))
 		    {
-		      case COMPLETE_PATH_NONE:
-		      case COMPLETE_PATH_AMBIGUOUS:
-			gdk_beep();
-			break;
+			if(!strcmp((const char *)prev_path, (const char *)path))
+			    gdk_beep();
 		    }
+
+		    g_free(prev_path);
+		    g_free(path);
 		}
 	    }
 	    SIGNAL_EMIT_STOP
@@ -650,27 +653,61 @@ static void PDialogPromptDragDataReceivedCB(
 	if((widget == NULL) || (dc == NULL) || (selection_data == NULL))
 	    return;
 
-	if((selection_data->data == NULL) || (selection_data->length <= 0))
+	if((selection_data->data == NULL) ||
+	   (selection_data->length <= 0)
+	)
 	    return;
 
-	if((info == 0) ||	/* "text/plain" */
-	   (info == 1) ||	/* "text/uri-list" */
-	   (info == 2)		/* "STRING" */
+	/* Handle by the target type
+	 *
+	 * String
+	 */
+	if((info == 0) ||	/* GUI_TARGET_NAME_TEXT_PLAIN */
+	   (info == 1) ||	/* GUI_TARGET_NAME_TEXT_URI_LIST */
+	   (info == 2)		/* GUI_TARGET_NAME_STRING */
 	)
 	{
-	    gint buf_len = selection_data->length;
-	    gchar *buf = (gchar *)g_malloc((buf_len + 1) * sizeof(gchar));
-	    memcpy(buf, selection_data->data, buf_len * sizeof(gchar));
-	    buf[buf_len] = '\0';
+	    gint len = selection_data->length;
+	    const gchar *ss = (const gchar *)selection_data->data;
+	    gchar *s;
 
-	    if(GTK_IS_ENTRY(widget))
+	    if(ss[len - 1] == '\0')
+		len--;
+
+	    s = (gchar *)g_malloc(len + (1 * sizeof(gchar)));
+	    if(s != NULL)
 	    {
-		GtkEntry *entry = GTK_ENTRY(widget);
-		gtk_entry_set_text(entry, buf);
-		gtk_entry_set_position(entry, -1);
-	    }
+		gchar *s2, *s_end;
 
-	    g_free(buf);
+		if(len > 0)
+		    memcpy(s, selection_data->data, len);
+		s[len] = '\0';
+
+		/* Remove any null deliminators within the string */
+		s2 = s;
+		s_end = s2 + len;
+		while(s2 < s_end)
+		{
+		    if(*s2 == '\0')
+			*s2 = ' ';
+		    s2++;
+		}
+
+		/* Insert the string */
+		if(GTK_IS_EDITABLE(widget))
+		{
+		    GtkEditable *editable = GTK_EDITABLE(widget);
+		    gint position = gtk_editable_get_position(editable);
+		    if(len > 0)
+			gtk_editable_insert_text(
+			    editable,
+			    s, len,
+			    &position
+			);
+		}
+
+		g_free(s);
+	    }
 	}
 }
 
@@ -728,7 +765,7 @@ static guint8 **PDialogGetMessageIconDataFromCode(pdialog_icon icon_code)
 	    d = (guint8 **)icon_security_32x32_xpm;
 	    break;
 	  case PDIALOG_ICON_PRINTER:
-	    d = (guint8 **)icon_print_32x32_xpm;
+	    d = (guint8 **)icon_print2_32x32_xpm;
 	    break;
 	  case PDIALOG_ICON_SPEAKER:
 	    d = (guint8 **)icon_sound_32x32_xpm;
@@ -747,7 +784,7 @@ static guint8 **PDialogGetMessageIconDataFromCode(pdialog_icon icon_code)
 #endif
 	    break;
 	  case PDIALOG_ICON_TERMINAL:
-	    d = (guint8 **)icon_terminal_32x32_xpm;
+	    d = (guint8 **)icon_terminal2_32x32_xpm;
 	    break;
 	  case PDIALOG_ICON_SETTINGS:
 	    d = (guint8 **)icon_tuning_32x32_xpm;
@@ -756,7 +793,7 @@ static guint8 **PDialogGetMessageIconDataFromCode(pdialog_icon icon_code)
 	    d = (guint8 **)icon_tools_32x32_xpm;
 	    break;
 	  case PDIALOG_ICON_MONITOR:
-	    d = (guint8 **)icon_monitor_32x32_xpm;
+	    d = (guint8 **)icon_monitor2_32x32_xpm;
 	    break;
 	  case PDIALOG_ICON_CLIPBOARD_EMPTY:
 	    d = (guint8 **)icon_clipboard_empty_32x32_xpm;
@@ -939,9 +976,9 @@ static pdialog_prompt_struct *PDialogPromptNewNexus(
 	if(TRUE)
 	{
 	    const GtkTargetEntry dnd_tar_types[] = {
-{"text/plain",				0,	0},
-{"text/uri-list",			0,	1},
-{"STRING",				0,	2}
+{GUI_TARGET_NAME_TEXT_PLAIN,	0,		0},
+{GUI_TARGET_NAME_TEXT_URI_LIST,	0,		1},
+{GUI_TARGET_NAME_STRING,	0,		2}
 	    };
 	    GtkWidget *w2;
 	    pulistbox_struct *pulistbox;
@@ -983,6 +1020,7 @@ static pdialog_prompt_struct *PDialogPromptNewNexus(
 		    GTK_OBJECT(w), "activate",
 		    GTK_SIGNAL_FUNC(PDialogEntryEnterCB), d
 		);
+		GUIEditableEndowPopupMenu(w, 0);
 		gtk_widget_show(w);
 		break;
 
@@ -993,6 +1031,7 @@ static pdialog_prompt_struct *PDialogPromptNewNexus(
 		    GTK_OBJECT(w), "activate",
 		    GTK_SIGNAL_FUNC(PDialogEntryEnterCB), d
 		);
+		GUIEditableEndowPopupMenu(w, 0);
 		gtk_widget_show(w);
 		break;
 
@@ -1039,6 +1078,7 @@ static pdialog_prompt_struct *PDialogPromptNewNexus(
 		    GTK_OBJECT(w2), "activate",
 		    GTK_SIGNAL_FUNC(PDialogEntryEnterCB), d
 		);
+		GUIEditableEndowPopupMenu(w2, 0);
 		gtk_widget_show(w);
 		break;
 
@@ -1164,7 +1204,9 @@ gint PDialogInit(void)
 	GdkWindow *window;
 	GtkAccelGroup *accelgrp;
 	GtkStyle *style;
-	GtkWidget *w, *parent, *parent2, *parent3;
+	GtkWidget	*w,
+			*parent, *parent2, *parent3,
+			*toplevel;
 	pdialog_struct *d = &pdialog;
 
 	/* Already initialized? */
@@ -1174,6 +1216,8 @@ gint PDialogInit(void)
 	/* Reset values */
 	memset(d, 0x00, sizeof(pdialog_struct));
 
+	d->toplevel = toplevel = gtk_window_new(GTK_WINDOW_DIALOG);
+	d->accelgrp = accelgrp = gtk_accel_group_new();
 	d->initialized = TRUE;
 	d->last_icon_code = PDIALOG_ICON_QUESTION;
 	d->last_transient_for = NULL;
@@ -1181,11 +1225,9 @@ gint PDialogInit(void)
 	d->response_val = NULL;
 	d->response_nvals = 0;
 
-	/* Keyboard accelerator group */
-	d->accelgrp = accelgrp = gtk_accel_group_new();
-
-	/* Toplevel */
-	d->toplevel = w = gtk_window_new(GTK_WINDOW_DIALOG);
+	/* Toplevel GtkWindow */
+	w = toplevel;
+	gtk_window_set_policy(GTK_WINDOW(w), TRUE, TRUE, TRUE);
 	gtk_window_set_title(GTK_WINDOW(w), "Enter Values");
 #ifdef PROG_NAME
 	gtk_window_set_wmclass(
@@ -1202,12 +1244,11 @@ gint PDialogInit(void)
 
 	    gdk_window_set_decorations(
 		window,
-		GDK_DECOR_BORDER | GDK_DECOR_TITLE | GDK_DECOR_MENU |
-		GDK_DECOR_MINIMIZE
+		GDK_DECOR_BORDER | GDK_DECOR_TITLE
 	    );
 	    gdk_window_set_functions(
 		window,
-		GDK_FUNC_MOVE | GDK_FUNC_MINIMIZE | GDK_FUNC_CLOSE
+		GDK_FUNC_MOVE | GDK_FUNC_CLOSE
 	    );
 
 	    geo.min_width = 100;
@@ -2381,7 +2422,6 @@ void PDialogDeleteAllPrompts(void)
 	gint i;
 	pdialog_struct *d = &pdialog;
 
-
 	for(i = 0; i < d->total_prompts; i++)
 	    PDialogPromptDelete(d->prompt[i]);
 	g_free(d->prompt);
@@ -2833,25 +2873,15 @@ void PDialogShutdown(void)
 	}
 	d->block_loop_level = 0;
 
-	/* Unmap dialog */
+	/* Unmap the dialog */
 	PDialogUnmap();
 
-	/* Delete all prompts on dialog */
+	/* Delete all the prompts on the dialog */
 	PDialogDeleteAllPrompts();
 
-	/* Begin destroying widgets */
-	GTK_WIDGET_DESTROY(d->submit_btn)
-	GTK_WIDGET_DESTROY(d->cancel_btn)
-	GTK_WIDGET_DESTROY(d->help_btn)
-
-	GTK_WIDGET_DESTROY(d->icon_pm)
-	GTK_WIDGET_DESTROY(d->message_label)
-	GTK_WIDGET_DESTROY(d->message_label_hbox)
-
-	GTK_WIDGET_DESTROY(d->main_vbox)
-	GTK_WIDGET_DESTROY(d->toplevel)
-
-	GTK_ACCEL_GROUP_UNREF(d->accelgrp)
+	/* Delete the dialog */
+	gtk_widget_destroy(d->toplevel);
+	gtk_accel_group_unref(d->accelgrp);
 
 	memset(d, 0x00, sizeof(pdialog_struct));
 }
