@@ -416,17 +416,17 @@ void WinNotebookSwitchPageCB(
 	if(win->freeze_count > 0)
 	    return;
 
+	/* Change in page? */
 	if(win->page_num != (win_page_num)page_num)
 	{
+	    /* Record the new page number */
 	    win->page_num = (win_page_num)page_num;
 	    switch(page_num)
 	    {
 	      case WIN_PAGE_NUM_SCAN:
 		break;
-
 	      case WIN_PAGE_NUM_RESULTS:
 		break;
-
 	      case WIN_PAGE_NUM_DB:
 		WinDBQueueUpdate(win);
 		break;
@@ -613,14 +613,14 @@ gint WinListEventCB(GtkWidget *widget, GdkEvent *event, gpointer data)
 	    }
 	    break;
 
-	  case GDK_2BUTTON_PRESS:
+	  case GDK_2BUTTON_PRESS:	/* Double-click */
 	    button = (GdkEventButton *)event;
 	    switch(button->button)
 	    {
 	      case GDK_BUTTON1:
 		if(widget == win->scan_clist)
 		{
-		    WinStartCB(NULL, win);
+		    WinStartCB(widget, win);
 		}
 		else if(widget == win->results_clist)
 		{
@@ -628,7 +628,7 @@ gint WinListEventCB(GtkWidget *widget, GdkEvent *event, gpointer data)
 		}
 		else if(widget == win->db_ctree)
 		{
-		    WinDBPatternDetailsCB(NULL, win);
+		    WinDBPatternDetailsCB(widget, win);
 		}
 		break;
 	    }
@@ -720,8 +720,6 @@ void WinListSelectRowCB(
 	    return;
 
 	core = CORE(win->core);
-	if(core == NULL)
-	    return;
 
 	/* If the row is not visible then scroll to make it visible */
 	if(gtk_clist_row_is_visible(clist, row) !=
@@ -1139,21 +1137,16 @@ void WinDBFindEntryCB(GtkWidget *widget, gpointer data)
 	}
 	else
 	{
-	    gchar *msg = g_strdup_printf(
-		"The text \"%s\" was not found",
-		needle
-	    );
 	    CDialogSetTransientFor(toplevel);
 	    CDialogGetResponse(
 		"Find Results",
-		msg,
+		"The string that you entered was not found.",
 		NULL,
 		CDIALOG_ICON_SEARCH,
 		CDIALOG_BTNFLAG_OK,
 		CDIALOG_BTNFLAG_OK
 	    );
 	    CDialogSetTransientFor(NULL);
-	    g_free(msg);
 	}
 
 	g_free(needle);
@@ -1329,7 +1322,7 @@ gint WinScanMonitorTOCB(gpointer data)
 		    WinUpdateTitle(win);
 
 		    /* Update the results status */
-		    shortened_path = SHORTEN_STRING(path, 27);
+		    shortened_path = SHORTEN_STRING(path, 25);
 		    msg = g_strdup_printf(
 			"%s (%ld/%ld): %s",
 			pfx, nscanned + 1l, total, shortened_path
@@ -1339,7 +1332,7 @@ gint WinScanMonitorTOCB(gpointer data)
 		    g_free(msg);
 
 		    /* Update the status bar message */
-		    shortened_path = SHORTEN_STRING(path, 45);
+		    shortened_path = SHORTEN_STRING(path, 40);
 		    msg = g_strdup_printf(
 			"%s (%ld/%ld): %s",
 			pfx, nscanned + 1l, total, shortened_path
@@ -1439,7 +1432,7 @@ gint WinScanMonitorTOCB(gpointer data)
 		    WinUpdateTitle(win);
 
 		    /* Update the results status */
-		    shortened_path = SHORTEN_STRING(path, 27);
+		    shortened_path = SHORTEN_STRING(path, 25);
 		    msg = g_strdup_printf(
 			"%s: %s",
 			pfx, shortened_path
@@ -1449,7 +1442,7 @@ gint WinScanMonitorTOCB(gpointer data)
 		    g_free(msg);
 
 		    /* Update the status bar message */
-		    shortened_path = SHORTEN_STRING(path, 45);
+		    shortened_path = SHORTEN_STRING(path, 40);
 		    msg = g_strdup_printf(
 			"%s: %s",
 			pfx, shortened_path
