@@ -5,6 +5,13 @@
 #include "win.h"
 
 
+extern void WinAnimIconDataReceivedCB(
+        GtkWidget *widget, GdkDragContext *dc,
+        gint x, gint y,
+        GtkSelectionData *selection_data, guint info, guint t,
+        gpointer data
+);
+
 extern void WinListDNDSetIcon(
 	GtkCList *clist, gint row, gint column
 ); 
