@@ -19,6 +19,11 @@ extern void WinScanListClear(win_struct *win);
 extern void WinScanListUpdateRow(
 	win_struct *win, gint row, const obj_struct *obj
 );
+extern void WinScanListTouchByLocation(
+        win_struct *win,
+        const gchar *location,
+        const gulong t
+);
 
 /* Results List */
 extern gint WinResultsListAppend(
