@@ -1,5 +1,6 @@
 #include <stdlib.h>
 #include <string.h>
+#include <errno.h>
 #include <time.h>
 #include <signal.h>
 #include <sys/stat.h>
@@ -51,6 +52,11 @@ void WinAddCB(GtkWidget *widget, gpointer data);
 static gchar *WinPDialogBrowseLocationCB(
 	gpointer p, gpointer data, gint prompt_num
 );
+static gint WinCheckObjectValidValues(
+	win_struct *win, obj_struct *obj,
+	const gboolean verbose
+);
+static void WinEdit(win_struct *win);
 void WinEditCB(GtkWidget *widget, gpointer data);
 void WinRemoveCB(GtkWidget *widget, gpointer data);
 void WinCutCB(GtkWidget *widget, gpointer data);
@@ -279,7 +285,7 @@ static gboolean WinQueryOverwrite(
 )
 {
 	gint response;
-	gchar *buf;
+	gchar *msg;
 	struct stat stat_buf;
 
 	/* Path not specified or object does not exist? */
@@ -287,7 +293,7 @@ static gboolean WinQueryOverwrite(
 	    return(TRUE);
 
 	/* Confirm overwrite */
-	buf = g_strdup_printf(
+	msg = g_strdup_printf(
 	    "Overwrite existing file:\n\n    %s\n",
 	    path
 	);
@@ -297,14 +303,14 @@ static gboolean WinQueryOverwrite(
 	CDialogSetTransientFor(toplevel);
 	response = CDialogGetResponse(
 	    "Confirm Overwrite",
-	    buf,
+	    msg,
 	    NULL,
 	    CDIALOG_ICON_WARNING,
 	    CDIALOG_BTNFLAG_YES | CDIALOG_BTNFLAG_NO,
 	    CDIALOG_BTNFLAG_NO
 	);
 	CDialogSetTransientFor(NULL);
-	g_free(buf);
+	g_free(msg);
 	switch(response)
 	{
 	  case CDIALOG_RESPONSE_YES:
@@ -535,12 +541,14 @@ void WinAddCB(GtkWidget *widget, gpointer data)
 	{
 	    gint new_row;
 
-	    /* Set default object values */
+	    /* Set the default values for the new object */
 	    obj->name = STRDUP("New Scan");
-	    obj->path = STRDUP(getenv("HOME"));
+	    obj->path = STRDUP(g_getenv("HOME"));
 	    obj->options = 0;
 	    obj->last_runned = 0l;
 
+	    gtk_clist_freeze(clist);
+
 	    /* Insert or append a new row on the scan list and
 	     * transfer the new object to it
 	     */
@@ -549,6 +557,8 @@ void WinAddCB(GtkWidget *widget, gpointer data)
 	    else
 		new_row = WinScanListAppend(win, obj);
 
+	    gtk_clist_thaw(clist);
+
 	    if(new_row > -1)
 	    {
 		/* Select the new row */
@@ -573,13 +583,13 @@ static gchar *WinPDialogBrowseLocationCB(
 	gpointer p, gpointer data, gint prompt_num
 )
 {
+	static gchar path[PATH_MAX];
 	gboolean status;
 	GtkWidget *toplevel;
-	fb_type_struct **ftype = NULL, *ftype_rtn = NULL;
-	gint total_ftypes = 0;
-	gchar **path_rtn = NULL;
-	gint total_path_rtns = 0;
-	static gchar path[PATH_MAX];
+	fb_type_struct **ftypes_list = NULL, *ftype_rtn = NULL;
+	gint nftypes = 0;
+	gchar **paths_list = NULL;
+	gint npaths = 0;
 	win_struct *win = WIN(data);
 	if((win == NULL) || FileBrowserIsQuery())
 	    return(NULL);
@@ -590,8 +600,8 @@ static gchar *WinPDialogBrowseLocationCB(
 
 	/* Create the file types list */
 	FileBrowserTypeListNew(
-	    &ftype, &total_ftypes,
-	    "*.*", "All files"
+	    &ftypes_list, &nftypes,
+	    "*.*", "All Files"
 	);                    
 
 	/* Query the user for the new location */
@@ -600,8 +610,8 @@ static gchar *WinPDialogBrowseLocationCB(
 	    "Select Location",
 	    "Select", "Cancel",
 	    PDialogGetPromptValue(prompt_num),
-	    ftype, total_ftypes,
-	    &path_rtn, &total_path_rtns,
+	    ftypes_list, nftypes,
+	    &paths_list, &npaths,
 	    &ftype_rtn
 	);
 	FileBrowserSetTransientFor(NULL);
@@ -609,8 +619,8 @@ static gchar *WinPDialogBrowseLocationCB(
 	/* Got user response? */
 	if(status)
 	{
-	    const gchar *s = (total_path_rtns > 0) ?
-		path_rtn[0] : NULL;
+	    const gchar *s = (npaths > 0) ?
+		paths_list[0] : NULL;
 	    if(!STRISEMPTY(s))
 	    {
 		strncpy(path, s, sizeof(path));
@@ -619,17 +629,105 @@ static gchar *WinPDialogBrowseLocationCB(
 	}
 
 	/* Delete the file types list */
-	FileBrowserDeleteTypeList(ftype, total_ftypes);
+	FileBrowserDeleteTypeList(ftypes_list, nftypes);
 
 	return(STRISEMPTY(path) ? NULL : path);
 }
 
+/*
+ *	Checks if the object has valid values.
+ */
+static gint WinCheckObjectValidValues(
+	win_struct *win, obj_struct *obj,
+	const gboolean verbose
+)
+{
+	gint status;
+	GtkWidget *toplevel;
+	core_struct *core;
+
+	if((win == NULL) || (obj == NULL))
+	    return(-2);
+
+	status = 0;
+	toplevel = win->toplevel;
+	core = win->core;
+
+	if(STRISEMPTY(obj->name))
+	{
+
+	    status = -2;
+	}
+	else
+	{
+
+
+	}
+
+	if(STRISEMPTY(obj->path))
+	{
+
+	    status = -2;
+	}
+	else
+	{
+	    /* Check if each path is valid */
+	    gchar **strv = g_strsplit(obj->path, ",", -1);
+	    if(strv != NULL)
+	    {
+		struct stat stat_buf;
+		gint i;
+		const gchar *path;
+
+		for(i = 0; strv[i] != NULL; i++)
+		{
+		    path = strv[i];
+
+		    /* Does this path have a problem? */
+		    if(stat((const char *)path, &stat_buf))
+		    {
+			const gint error_code = (gint)errno;
+			if(verbose)
+			{
+			    gchar *msg = g_strdup_printf(
+				"%s:\n\n    %s",
+				g_strerror(error_code),
+				path
+			    );
+#ifdef HAVE_EDV2   
+			    EDVPlaySoundWarning(core->edv_ctx);
+#endif
+                            CDialogSetTransientFor(toplevel);
+                            CDialogGetResponse(
+				"Scan Item Warning",
+				msg,
+				NULL,
+                                CDIALOG_ICON_WARNING,
+                                CDIALOG_BTNFLAG_OK,
+                                CDIALOG_BTNFLAG_OK
+                            );
+			    g_free(msg);
+			    CDialogSetTransientFor(NULL);
+			}
+			if(status == 0)
+			    status = -1;
+			break;
+		    }
+		}
+
+		g_strfreev(strv);
+	    }
+	}
+
+	return(status);
+}
+
 /*
  *	Edit.
  *
  *	Edits the selected scan item.
  */
-void WinEditCB(GtkWidget *widget, gpointer data)
+static void WinEdit(win_struct *win)
 {
 	gchar **strv;
 	gint strc, row;
@@ -638,16 +736,10 @@ void WinEditCB(GtkWidget *widget, gpointer data)
 	GtkCList *clist;
 	obj_struct *obj;
 	core_struct *core;
-	win_struct *win = WIN(data);
+
 	if((win == NULL) || PDialogIsQuery())
 	    return;
 
-	if(win->freeze_count > 0)
-	    return;
-
-	if((widget != NULL) ? !GTK_WIDGET_SENSITIVE(widget) : FALSE)
-	    return;
-
 	toplevel = win->toplevel;
 	clist = GTK_CLIST(win->scan_clist);
 	core = CORE(win->core);
@@ -735,7 +827,7 @@ void WinEditCB(GtkWidget *widget, gpointer data)
 	    GTK_WINDOW(PDialogGetToplevel()), NULL
 	);
 /*	PDialogSetTransientFor(NULL); */
-	if((strv != NULL) && (strc > 4))
+	if((strv != NULL) && (strc >= 5))
 	{
 	    g_free(obj->name);
 	    obj->name = STRDUP(strv[0]);
@@ -761,6 +853,14 @@ void WinEditCB(GtkWidget *widget, gpointer data)
 	    WinScanListUpdateRow(win, row, obj);
 	    WinScanSettingsUpdate(win, obj);
 	    WinUpdate(win);
+
+	    /* Check for and report any problems with this
+	     * scan item
+	     */
+	    WinCheckObjectValidValues(
+		win, obj,
+		TRUE				/* Verbose */
+	    );
 	}
 
 	PDialogDeleteAllPrompts();
@@ -768,6 +868,30 @@ void WinEditCB(GtkWidget *widget, gpointer data)
 	WinSetBusy(win, FALSE);
 }
 
+/*
+ *	Edit.
+ *
+ *	Edits the selected scan item.
+ */
+void WinEditCB(GtkWidget *widget, gpointer data)
+{
+	win_struct *win = WIN(data);
+	if((win == NULL) || PDialogIsQuery())
+	    return;
+
+	if((widget != NULL) ? !GTK_WIDGET_SENSITIVE(widget) : FALSE)
+	    return;
+
+	if(win->freeze_count > 0)
+	    return;
+
+	win->freeze_count++;
+
+	WinEdit(win);
+
+	win->freeze_count--;
+}
+
 /*
  *	Remove.
  *
@@ -815,16 +939,16 @@ void WinRemoveCB(GtkWidget *widget, gpointer data)
 	    gint response;
 	    const gint nobjs = g_list_length(obj_list);
 	    obj_struct *obj = (nobjs == 1) ? OBJ(obj_list->data) : NULL;
-	    gchar *buf;
+	    gchar *msg;
 
 	    /* Format confirm delete message */
 	    if((obj != NULL) ? !STRISEMPTY(obj->name) : FALSE)
-		buf = g_strdup_printf(
+		msg = g_strdup_printf(
 		    "Delete scan item \"%s\"?",
 		    obj->name
 		);
 	    else
-		buf = g_strdup_printf(
+		msg = g_strdup_printf(
 		    "Delete %i selected scan items?",
 		    nobjs
 		);
@@ -836,14 +960,14 @@ void WinRemoveCB(GtkWidget *widget, gpointer data)
 	    CDialogSetTransientFor(toplevel);
 	    response = CDialogGetResponse(
 		"Confirm Delete",
-		buf,
+		msg,
 		NULL,
 		CDIALOG_ICON_WARNING,
 		CDIALOG_BTNFLAG_YES | CDIALOG_BTNFLAG_NO,
 		CDIALOG_BTNFLAG_NO
 	    );
 	    CDialogSetTransientFor(NULL);
-	    g_free(buf);
+	    g_free(msg);
 	    if(response != CDIALOG_RESPONSE_YES)
 	    {
 		g_list_free(obj_list);
@@ -862,7 +986,7 @@ void WinRemoveCB(GtkWidget *widget, gpointer data)
 	}
 	gtk_clist_thaw(clist);
 
-	/* Delete objects list */
+	/* Delete the objects list */
 	g_list_free(obj_list);
 
 	WinUpdate(win);
@@ -1038,8 +1162,8 @@ void WinPasteCB(GtkWidget *widget, gpointer data)
 	/* Get the data from the clipboard and convert it into a
 	 * list of objects
 	 *
-	 * First attempt to get the data as DND_TARGET_SCAN_ITEM,
-	 * then as "STRING".
+	 * First attempt to get the data as AVSCAN_DND_TARGET_SCAN_ITEM,
+	 * then as GUI_TARGET_NAME_STRING.
 	 */
 	got_data = FALSE;
 	obj_list = NULL;
@@ -1089,14 +1213,15 @@ void WinPasteCB(GtkWidget *widget, gpointer data)
 	    if(s != NULL)
             {
                 got_data = TRUE;
-                obj_list = ObjDDEBufferParsePath(s, STRLEN(s));
+                obj_list = ObjDDEBufferParsePath((guint8 *)s, STRLEN(s));
                 g_free(s);
             }
 	}
 
 	if(got_data)
 	{
-	    /* Parse the buffer into a list of objects */
+	    /* Paste the objects into the list */
+	    gint last_new_row = -1;
 	    GList *glist = clist->selection_end;
 	    const gint row = (glist != NULL) ? (gint)glist->data : -1;
 	    obj_struct *obj;
@@ -1108,7 +1233,10 @@ void WinPasteCB(GtkWidget *widget, gpointer data)
 	    {
 		gint ins_row = row;
 
-		for(glist = obj_list; glist != NULL; glist = g_list_next(glist))
+		for(glist = obj_list;
+		    glist != NULL;
+		    glist = g_list_next(glist)
+		)
  		{
 		    obj = OBJ(glist->data);
 		    ins_row = WinScanListInsert(
@@ -1116,12 +1244,15 @@ void WinPasteCB(GtkWidget *widget, gpointer data)
 		    );
 		    if(ins_row < 0)
 			break;
+
+		    last_new_row = ins_row;
+
 		    ins_row++;
 		}
  	    }
 	    else
 	    {
-		gint new_row;
+		gint new_row = -1;
 
 		for(glist = obj_list; glist != NULL; glist = g_list_next(glist))
 		{
@@ -1129,10 +1260,25 @@ void WinPasteCB(GtkWidget *widget, gpointer data)
 		    new_row = WinScanListAppend(win, ObjCopy(obj));
 		    if(new_row < 0)
 			break;
+
+		    last_new_row = new_row;
 		}
 	    }
 
 	    gtk_clist_thaw(clist);
+
+	    /* If the row is not visible then scroll to make it visible */
+	    if(last_new_row > -1)
+	    {
+		if(gtk_clist_row_is_visible(clist, last_new_row) !=
+		    GTK_VISIBILITY_FULL
+		)
+                    gtk_clist_moveto(
+			clist,
+			last_new_row, -1,	/* Row, column */
+			0.5f, 0.0f		/* Row, column */
+		    );
+	    }
 	}
 	else
 	{
@@ -1143,7 +1289,7 @@ void WinPasteCB(GtkWidget *widget, gpointer data)
             CDialogGetResponse(  
                 "Paste Failed",
 "The clipboard is either empty or contains data\n\
-not supported by this application.",
+that is not supported by this application.",
                 NULL,
                 CDIALOG_ICON_WARNING,
                 CDIALOG_BTNFLAG_OK,
@@ -1225,13 +1371,9 @@ void WinInvertSelectionCB(GtkWidget *widget, gpointer data)
  */
 void WinStartCB(GtkWidget *widget, gpointer data)
 {
-	gint i;
-	gchar *location, **strv;
 	GList *paths_list;
 	GtkWidget *toplevel;
-	GtkCList *clist;
 	avscan_options options;
-	obj_struct *obj;
 	core_struct *core;
 	win_struct *win = WIN(data);
 	if(win == NULL)
@@ -1244,7 +1386,6 @@ void WinStartCB(GtkWidget *widget, gpointer data)
 	    return;
 
 	toplevel = win->toplevel;
-	clist = GTK_CLIST(win->scan_clist);
 	core = CORE(win->core);
 
 	/* Is there a scan or update already in progress? */
@@ -1274,30 +1415,12 @@ current scan or update before starting a new scan.",
 
 	WinSetBusy(win, TRUE);
 
-	/* Get the scan values */
-	location = STRDUP(
-	    gtk_entry_get_text(GTK_ENTRY(win->location_entry))
-	);
-	strv = g_strsplit(location, ",", -1);
-	paths_list = NULL;
-	if(strv != NULL)
-	{
-	    gint i;
-	    for(i = 0; strv[i] != NULL; i++)
-		paths_list = g_list_append(paths_list, STRDUP(strv[i]));
-	    g_strfreev(strv);
-	}
-
-	options = 0;
-	if(GTK_TOGGLE_BUTTON_GET_ACTIVE(win->recursive_check))
-	    options |= AVSCAN_OPT_RECURSIVE;
-	if(GTK_TOGGLE_BUTTON_GET_ACTIVE(win->executables_only_check))
-	    options |= AVSCAN_OPT_EXECUTABLES_ONLY;
-	if(GTK_TOGGLE_BUTTON_GET_ACTIVE(win->ignore_links_check))
-	    options |= AVSCAN_OPT_IGNORE_LINKS;
+	/* Get the paths list and scan options */
+	paths_list = WinGetCurrentPathsList(win);
+	options = WinGetCurrentOptions(win);
 
 	/* Scan location not specified? */
-	if(STRISEMPTY(location))
+	if(paths_list == NULL)
 	{
 #ifdef HAVE_EDV2  
 	    EDVPlaySoundWarning(core->edv_ctx);
@@ -1305,7 +1428,7 @@ current scan or update before starting a new scan.",
 	    CDialogSetTransientFor(toplevel);
 	    CDialogGetResponse(
 		"Scan Failed",
-"The scan location has not been specified",
+"The scan location was not been specified.",
 		NULL,
 		CDIALOG_ICON_WARNING,
 		CDIALOG_BTNFLAG_OK,
@@ -1313,50 +1436,35 @@ current scan or update before starting a new scan.",
 	    ); 
 	    CDialogSetTransientFor(NULL);
 
-	    g_list_foreach(paths_list, (GFunc)g_free, NULL);
-	    g_list_free(paths_list);
-	    g_free(location);
-
 	    WinSetBusy(win, FALSE);
 	    return;
 	}
 
 
-	/* Get the selected row and see if the scan item object's
-	 * location matches the specified location
+	/* Find the scan item who's location matches the specified
+	 * location and updates its last runned time
 	 */
-	for(i = 0; i < clist->rows; i++)
-	{
-	    obj = OBJ(gtk_clist_get_row_data(clist, i));
-	    if((obj != NULL) ? STRISEMPTY(obj->path) : TRUE)
-		continue;
+	WinScanListTouchByLocation(
+	    win,
+	    WinGetCurrentLocation(win),
+	    (gulong)time(NULL)
+	);
 
-	    /* Object's location matches the specified location? */
-	    if(!strcmp(obj->path, location))
-	    {
-		/* Update this object's last runned time */
-		obj->last_runned = (gulong)time(NULL);
-		WinScanListUpdateRow(win, i, obj);
-	    }
-	}
-
-	/* Start scan */
+	/* Start the scan */
 	WinScanProcessStart(
 	    win,
-	    NULL,		/* Use the already database path from
+	    NULL,		/* Use the database path specified in
 				 * the configuration */
 	    paths_list,		/* List of objects to scan */
 	    options
 	);
 
-	/* Switch to results page */
-	gtk_notebook_set_page(
-	    GTK_NOTEBOOK(win->notebook), (gint)WIN_PAGE_NUM_RESULTS
-	);
-
+	/* Delete the paths list */
 	g_list_foreach(paths_list, (GFunc)g_free, NULL);
 	g_list_free(paths_list);
-	g_free(location);
+
+	/* Switch to the results page */
+	WinSwitchPage(win, WIN_PAGE_NUM_RESULTS);
 
 	WinSetBusy(win, FALSE);
 }
@@ -1479,9 +1587,9 @@ void WinLocationCB(GtkWidget *widget, gpointer data)
 	GtkWidget *toplevel;
 	GtkEntry *entry;
 	fb_type_struct **ftype = NULL, *ftype_rtn = NULL;
-	gint total_ftypes = 0;
-	gchar **path_rtn = NULL;
-	gint total_path_rtns = 0;
+	gint nftypes = 0;
+	gchar **paths_list = NULL;
+	gint npaths = 0;
 	win_struct *win = WIN(data);
 	if((win == NULL) || FileBrowserIsQuery())
 	    return;
@@ -1493,7 +1601,7 @@ void WinLocationCB(GtkWidget *widget, gpointer data)
 	    return;
 
 	toplevel = win->toplevel;
-	entry = GTK_ENTRY(win->location_entry);
+	entry = GTK_ENTRY(win->scan_location_entry);
 
 	prev_location = gtk_entry_get_text(entry);
 	s = strrchr(prev_location, ',');
@@ -1504,8 +1612,8 @@ void WinLocationCB(GtkWidget *widget, gpointer data)
 
 	/* Create file types list */
 	FileBrowserTypeListNew(
-	    &ftype, &total_ftypes,
-	    "*.*", "All files"
+	    &ftype, &nftypes,
+	    "*.*", "All Files"
 	);
 
 	/* Query user for path */
@@ -1514,8 +1622,8 @@ void WinLocationCB(GtkWidget *widget, gpointer data)
 	    "Select Location",
 	    "Select", "Cancel",
 	    prev_location,
-	    ftype, total_ftypes,
-	    &path_rtn, &total_path_rtns,
+	    ftype, nftypes,
+	    &paths_list, &npaths,
 	    &ftype_rtn
 	);
 	FileBrowserSetTransientFor(NULL);
@@ -1527,9 +1635,9 @@ void WinLocationCB(GtkWidget *widget, gpointer data)
 	    gchar *s, *location = STRDUP("");
 	    const gchar *path;
 
-	    for(i = 0; i < total_path_rtns; i++)
+	    for(i = 0; i < npaths; i++)
 	    {
-		path = path_rtn[i];
+		path = paths_list[i];
 		if(STRISEMPTY(path))
 		    continue;
 
@@ -1548,7 +1656,7 @@ void WinLocationCB(GtkWidget *widget, gpointer data)
 	}
 
 	/* Delete the file types list */
-	FileBrowserDeleteTypeList(ftype, total_ftypes);
+	FileBrowserDeleteTypeList(ftype, nftypes);
 
 	WinSetBusy(win, FALSE);
 }
@@ -1574,12 +1682,12 @@ void WinRecursiveCB(GtkWidget *widget, gpointer data)
 	win->freeze_count++;
 	WinSetBusy(win, TRUE);
 
-	v = GTK_TOGGLE_BUTTON_GET_ACTIVE(win->recursive_check) ? FALSE : TRUE;
+	v = GTK_TOGGLE_BUTTON_GET_ACTIVE(win->scan_recursive_check) ? FALSE : TRUE;
 	GUIMenuItemSetCheck(
 	    win->recursive_micheck, v, TRUE
 	);
 	gtk_toggle_button_set_active(
-	    GTK_TOGGLE_BUTTON(win->recursive_check), v
+	    GTK_TOGGLE_BUTTON(win->scan_recursive_check), v
 	);  
 
 	WinUpdate(win);
@@ -1609,12 +1717,12 @@ void WinExecutablesOnlyCB(GtkWidget *widget, gpointer data)
 	win->freeze_count++;
 	WinSetBusy(win, TRUE);
 
-	v = GTK_TOGGLE_BUTTON_GET_ACTIVE(win->executables_only_check) ? FALSE : TRUE;
+	v = GTK_TOGGLE_BUTTON_GET_ACTIVE(win->scan_executables_only_check) ? FALSE : TRUE;
 	GUIMenuItemSetCheck(
 	    win->executables_only_micheck, v, TRUE
 	);
 	gtk_toggle_button_set_active(
-	    GTK_TOGGLE_BUTTON(win->executables_only_check), v
+	    GTK_TOGGLE_BUTTON(win->scan_executables_only_check), v
 	);  
 
 	WinUpdate(win);
@@ -1644,12 +1752,12 @@ void WinIgnoreLinksCB(GtkWidget *widget, gpointer data)
 	win->freeze_count++;
 	WinSetBusy(win, TRUE);
 
-	v = GTK_TOGGLE_BUTTON_GET_ACTIVE(win->ignore_links_check) ? FALSE : TRUE;
+	v = GTK_TOGGLE_BUTTON_GET_ACTIVE(win->scan_ignore_links_check) ? FALSE : TRUE;
 	GUIMenuItemSetCheck(
 	    win->ignore_links_micheck, v, TRUE
 	);
 	gtk_toggle_button_set_active(
-	    GTK_TOGGLE_BUTTON(win->ignore_links_check), v
+	    GTK_TOGGLE_BUTTON(win->scan_ignore_links_check), v
 	);
 
 	WinUpdate(win);
@@ -2023,6 +2131,7 @@ void WinResultsRecycleCB(GtkWidget *widget, gpointer data)
 		g_free(path);
 	    }
 	}
+	gtk_clist_columns_autosize(clist);
 	gtk_clist_thaw(clist);
 	win->freeze_count--;
 
@@ -2162,9 +2271,9 @@ void WinResultsMoveCB(GtkWidget *widget, gpointer data)
 	    return;
 	}
 	/* Destination does not exist? */
-	if(stat(dest_path, &stat_buf))
+	if(stat((const char *)dest_path, &stat_buf))
 	{
-	    gchar *buf = g_strdup_printf(
+	    gchar *msg = g_strdup_printf(
 "Destination directory does not exist:\n\
 \n\
     %s\n",
@@ -2175,13 +2284,13 @@ void WinResultsMoveCB(GtkWidget *widget, gpointer data)
 #endif
 	    CDialogSetTransientFor(toplevel);
 	    CDialogGetResponse(
-		"Move Failed", buf, NULL,
+		"Move Failed", msg, NULL,
 		CDIALOG_ICON_ERROR,
 		CDIALOG_BTNFLAG_OK,
 		CDIALOG_BTNFLAG_OK
 	    );
 	    CDialogSetTransientFor(NULL);
-	    g_free(buf);
+	    g_free(msg);
 
 	    g_list_free(obj_list);
 	    g_free(name);
@@ -2202,7 +2311,7 @@ void WinResultsMoveCB(GtkWidget *widget, gpointer data)
 	    CDialogSetTransientFor(toplevel);
 	    CDialogGetResponse(
 		"Move Failed",
-		"Destination is not a directory",
+		"Destination is not a directory.",
 		NULL,
 		CDIALOG_ICON_ERROR,
 		CDIALOG_BTNFLAG_OK,
@@ -2260,7 +2369,8 @@ void WinResultsMoveCB(GtkWidget *widget, gpointer data)
 		g_free(old_path);
 		g_free(new_path);
 	    }
-	}    
+	} 
+	gtk_clist_columns_autosize(clist);
 	gtk_clist_thaw(clist);
 	win->freeze_count--;  
 
@@ -2526,9 +2636,9 @@ void WinResultsOpenCB(GtkWidget *widget, gpointer data)
 	gboolean status;
 	GtkWidget *toplevel;
 	fb_type_struct **ftype = NULL, *ftype_rtn = NULL;
-	gint total_ftypes = 0;
-	gchar **path_rtn = NULL;
-	gint total_path_rtns = 0;
+	gint nftypes = 0;
+	gchar **paths_list = NULL;
+	gint npaths = 0;
 	win_struct *win = WIN(data);
 	if((win == NULL) || FileBrowserIsQuery())
 	    return;
@@ -2545,12 +2655,12 @@ void WinResultsOpenCB(GtkWidget *widget, gpointer data)
 
 	/* Create file types list */
 	FileBrowserTypeListNew(     
-	    &ftype, &total_ftypes,
+	    &ftype, &nftypes,
 	    ".log", "Scan Results Log"
 	);
 	FileBrowserTypeListNew(
-	    &ftype, &total_ftypes,
-	    "*.*", "All files"
+	    &ftype, &nftypes,
+	    "*.*", "All Files"
 	);
 
 	/* Query user */
@@ -2559,8 +2669,8 @@ void WinResultsOpenCB(GtkWidget *widget, gpointer data)
 	    "Open Scan Results Log",
 	    "Open", "Cancel",
 	    NULL,
-	    ftype, total_ftypes,
-	    &path_rtn, &total_path_rtns,
+	    ftype, nftypes,
+	    &paths_list, &npaths,
 	    &ftype_rtn
 	);
 	FileBrowserSetTransientFor(NULL);
@@ -2568,8 +2678,8 @@ void WinResultsOpenCB(GtkWidget *widget, gpointer data)
 	/* Got user response? */
 	if(status)
 	{
-	    const gchar *new_path = (total_path_rtns > 0) ?
-		path_rtn[0] : NULL;
+	    const gchar *new_path = (npaths > 0) ?
+		paths_list[0] : NULL;
 	    if(!STRISEMPTY(new_path))
 	    {
 		/* Open the results log */
@@ -2578,7 +2688,7 @@ void WinResultsOpenCB(GtkWidget *widget, gpointer data)
 	}
 	 
 	/* Delete the file types list */
-	FileBrowserDeleteTypeList(ftype, total_ftypes);
+	FileBrowserDeleteTypeList(ftype, nftypes);
 
 	WinSetBusy(win, FALSE);
 }
@@ -2593,9 +2703,9 @@ void WinResultsSaveAsCB(GtkWidget *widget, gpointer data)
 	gboolean status;
 	GtkWidget *toplevel;
 	fb_type_struct **ftype = NULL, *ftype_rtn = NULL;
-	gint total_ftypes = 0;
-	gchar **path_rtn = NULL;
-	gint total_path_rtns = 0;
+	gint nftypes = 0;
+	gchar **paths_list = NULL;
+	gint npaths = 0;
 	core_struct *core;
 	win_struct *win = WIN(data);
 	if(win == NULL)             
@@ -2614,12 +2724,12 @@ void WinResultsSaveAsCB(GtkWidget *widget, gpointer data)
 
 	/* Create file types list */
 	FileBrowserTypeListNew(     
-	    &ftype, &total_ftypes,
+	    &ftype, &nftypes,
 	    ".log", "Scan Results Log"
 	);
 	FileBrowserTypeListNew(     
-	    &ftype, &total_ftypes,
-	    "*.*", "All files"
+	    &ftype, &nftypes,
+	    "*.*", "All Files"
 	);
 
 	/* Query user */
@@ -2628,8 +2738,8 @@ void WinResultsSaveAsCB(GtkWidget *widget, gpointer data)
 	    "Save Scan Results Log As",
 	    "Save", "Cancel",
 	    NULL,                       /* Initial path */
-	    ftype, total_ftypes,
-	    &path_rtn, &total_path_rtns,
+	    ftype, nftypes,
+	    &paths_list, &npaths,
 	    &ftype_rtn
 	);
 	FileBrowserSetTransientFor(NULL);
@@ -2637,8 +2747,8 @@ void WinResultsSaveAsCB(GtkWidget *widget, gpointer data)
 	/* Got user response? */
 	if(status)
 	{
-	    const gchar *new_path = (total_path_rtns > 0) ?
-		path_rtn[0] : NULL;
+	    const gchar *new_path = (npaths > 0) ?
+		paths_list[0] : NULL;
 	    if(!STRISEMPTY(new_path))
 	    {
 		/* Do overwrite check */
@@ -2651,7 +2761,7 @@ void WinResultsSaveAsCB(GtkWidget *widget, gpointer data)
 	}
 
 	/* Delete the file types list */
-	FileBrowserDeleteTypeList(ftype, total_ftypes);
+	FileBrowserDeleteTypeList(ftype, nftypes);
 
 	/* Reset due to possible file related change */
 	FileBrowserReset();
@@ -2897,9 +3007,9 @@ void WinDBLocationCB(GtkWidget *widget, gpointer data)
 	gboolean status;
 	GtkWidget *toplevel;
 	fb_type_struct **ftype = NULL, *ftype_rtn = NULL;
-	gint total_ftypes = 0;
-	gchar **path_rtn = NULL;
-	gint total_path_rtns = 0;
+	gint nftypes = 0;
+	gchar **paths_list = NULL;
+	gint npaths = 0;
 	cfg_item_struct *cfg_list;
 	core_struct *core;
 	win_struct *win = WIN(data);
@@ -2921,13 +3031,13 @@ void WinDBLocationCB(GtkWidget *widget, gpointer data)
 	/* Create file types list */
 #ifdef HAVE_CLAMAV
 	FileBrowserTypeListNew(
-	    &ftype, &total_ftypes,
+	    &ftype, &nftypes,
 	    ".cvd", "Clam Antivirus Database"
 	);
 #endif
 	FileBrowserTypeListNew(
-	    &ftype, &total_ftypes,
-	    "*.*", "All files"
+	    &ftype, &nftypes,
+	    "*.*", "All Files"
 	);                    
 
 	/* Query user for path */
@@ -2936,8 +3046,8 @@ void WinDBLocationCB(GtkWidget *widget, gpointer data)
 	    "Set Virus Scanner Database Location",
 	    "Set", "Cancel",
 	    CFGItemListGetValueS(cfg_list, CFG_PARM_DB_LOCATION),
-	    ftype, total_ftypes,
-	    &path_rtn, &total_path_rtns,
+	    ftype, nftypes,
+	    &paths_list, &npaths,
 	    &ftype_rtn
 	);
 	FileBrowserSetTransientFor(NULL);
@@ -2945,8 +3055,8 @@ void WinDBLocationCB(GtkWidget *widget, gpointer data)
 	/* Got user response? */
 	if(status) 
 	{
-	    const gchar *path = (total_path_rtns > 0) ?
-		path_rtn[0] : NULL;
+	    const gchar *path = (npaths > 0) ?
+		paths_list[0] : NULL;
 	    if(!STRISEMPTY(path))
 	    {
 		/* Set new virus database location */
@@ -2967,7 +3077,7 @@ void WinDBLocationCB(GtkWidget *widget, gpointer data)
 	}
 
 	/* Delete the file types list */
-	FileBrowserDeleteTypeList(ftype, total_ftypes);
+	FileBrowserDeleteTypeList(ftype, nftypes);
 
 	WinSetBusy(win, FALSE); 
 }
@@ -3220,7 +3330,7 @@ void WinHelpUpdatingCB(GtkWidget *widget, gpointer data)
  */
 void WinHelpAboutCB(GtkWidget *widget, gpointer data)
 {
-	gchar *s, *av_engine_name_version;
+	gchar *msg, *av_engine_name_version;
 	GtkWidget *toplevel;
 	win_struct *win = WIN(data);
 	if(win == NULL)
@@ -3237,7 +3347,7 @@ void WinHelpAboutCB(GtkWidget *widget, gpointer data)
 	toplevel = win->toplevel;
 
 	av_engine_name_version = AVScanGetAVEngineNameVersionString();
-	s = g_strdup_printf(
+	msg = g_strdup_printf(
 PROG_NAME_FULL "\n\
 Version " PROG_VERSION "\n\
 \n\
@@ -3249,20 +3359,20 @@ AntiVirus Engine: %s",
 	    (av_engine_name_version != NULL) ?
 		av_engine_name_version : "None"
 	);
-	free(av_engine_name_version);
+	g_free(av_engine_name_version);
 
 	CDialogSetTransientFor(toplevel);
 	CDialogGetResponseIconData(
 	    "About " PROG_NAME_FULL,
-	    s,
+	    msg,
 	    NULL,
 	    (guint8 **)icon_avscan_32x32_xpm,
 	    CDIALOG_BTNFLAG_OK,
 	    CDIALOG_BTNFLAG_OK
 	);
+	g_free(msg);
 	CDialogSetTransientFor(NULL);
 
-	free(s);
 
 	WinSetBusy(win, FALSE);
 }
